version 13
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    global baseline_condition baseline
    global young_condition age >= 65 & age <= 70
    global old_condition age >85
    global cancer_condition cancer
    global nonwhite_condition race
    global ami_condition ami
    global metastatic_condition metastatic
    global old_metastatic_condition (age>85) & metastatic
    foreach s in jan event {
        make_sample `s'
        clean_vars `s'
        phat_table `s'
    }
    phat_table_30_event
end

program make_sample
    args s
    if "`s'"=="jan" local s_name 1jan
    if "`s'"=="event" local s_name event
    use ../external/test_samples/`s'_sample, clear
    merge 1:1 bene_id using ../external_links/`s'/`s_name'2008, ///
      assert(2 3) keep(3) keepusing(age mort365 race) nogen
    merge 1:1 bene_id using ../external/`s'_chronic/chronic_y08.dta, ///
      assert(2 3) keep(3) keepusing(cncr* ami) nogen
    foreach h in 03 36 69 912 {
        merge 1:1 bene_id using ../external/`s'_gagne/gn_m`h'_y08, ///
          assert(1 2 3) keep(1 3) keepusing(*metastatic_romano*) nogen
    }
    save ../temp/`s'_merged, replace
end

program clean_vars
    args s
    use ../temp/`s'_merged, clear
    gen baseline = 1
    gen cancer = cncrbrst | cncrclrc | cncrprst | cncrlung | cncrendm
    foreach var of varlist *metastatic* {
        replace `var' = 0 if `var'==.
    }
    gen metastatic = (m03metastatic_romano + m36metastatic_romano + ///
      m69metastatic_romano + m912metastatic_romano) > 0
    gen old_metastatic = (age > 85) & metastatic 
    gen phat_trans = ln(phat/(1-phat))
    gen over_half_dead = phat > 0.5 & mort365
    gen over_eighty_dead = phat > 0.8 & mort365
    replace over_half_dead = . if !mort365
    replace over_eighty_dead = . if !mort365
    if "`s'"=="event" {
        gen over_half_dead30 = phat30 > 0.5 & mort30
        replace over_half_dead30 = . if !mort30
        gen over_eighty_dead30 = phat30 > 0.8 & mort30
        replace over_eighty_dead30 = . if !mort30
    }
    save ../temp/`s'_cleaned, replace
end

program phat_table
    args s
    use ../temp/`s'_cleaned, clear
    local stats (r(N), avg_mort, r(p75), r(p95), r(p99))
    display "`stats'"
    foreach type in baseline old cancer metastatic {
        preserve
        keep if ${`type'_condition}
        sum over_half_dead
        local over_half = r(mean)
        sum over_eighty_dead
        local over_eighty = r(mean)
        sum mort365
        scalar avg_mort = r(mean)
        sum phat, d
        matrix `s'_phat_stats = nullmat(`s'_phat_stats) \ (`stats', `over_half', `over_eighty')
        restore
    }
    matrix_to_txt, saving(../output/tables/`s'_phat_stats.txt) ///
      mat(`s'_phat_stats) format(%20.4f) ///
      title(<tab:`s'_phat_stats>) replace
    clear
    svmat `s'_phat_stats
    label var `s'_phat_stats1 "N"
    label var `s'_phat_stats2 "Mortality Rate"
    label var `s'_phat_stats3 "75th Percentile"
    label var `s'_phat_stats4 "95th Percentile"
    label var `s'_phat_stats5 "99th Percentile"
    label var `s'_phat_stats6 "Share of dead with phat > 0.5"
    if "`s'"=="jan" {
        export excel jan_phat_stats* using ../../Liran/exhibits.xls, sheetmodify sheet("E#B5") ///
          firstrow(varlabels)
    }
    if "`s'"=="event" {
        save ../temp/event_year, replace
    }
end

program phat_table_30_event
    use ../temp/event_cleaned, clear
    matrix drop event_phat_stats
    local stats (r(N), avg_mort, r(p75), r(p95), r(p99))
    display "`stats'"
    foreach type in baseline old cancer metastatic {
        preserve
        keep if ${`type'_condition}
        sum over_half_dead30
        local over_half = r(mean)
        sum over_eighty_dead30
        local over_eighty = r(mean)
        sum mort30
        scalar avg_mort = r(mean)
        sum phat30, d
        matrix event_phat_stats = nullmat(event_phat_stats) \ (`stats', `over_half', `over_eighty')
        restore
    }
    clear
    svmat event_phat_stats
    label var event_phat_stats1 "N"
    label var event_phat_stats2 "Mortality Rate"
    label var event_phat_stats3 "75th Percentile"
    label var event_phat_stats4 "95th Percentile"
    label var event_phat_stats5 "99th Percentile"
    label var event_phat_stats6 "Share of dead with phat > 0.5"
    save ../temp/event_month, replace
    use ../temp/event_year, clear
    append using ../temp/event_month
    export excel event_phat_stats* using ../../Liran/exhibits.xls, ///
      sheetmodify sheet("E#C2") firstrow(varlabels)
end

* EXECUTE
main
