version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    build_jan_sample
    foreach s in jan { 
        ventile_collapse `s'
        mortality_by_phat `s'
    }
end

program build_jan_sample
    use ../external/test_samples/jan_sample.dta, clear
    save ../temp/jan, replace
end

program ventile_collapse
    args s
    use ../temp/`s'.dta, clear
    xtile phat_ventiles = phat, nq(20)
    collapse (mean) phat mort, by(phat_ventiles)
    save ../temp/collapsed_`s', replace
end

program mortality_by_phat
    args s
    use ../temp/collapsed_`s'.dta, clear
    sum phat
    twoway scatter mort phat || function y = x, range(`r(min)' `r(max)') ///
      xtitle("Mean Phat") ///
      ytitle("Share of patients who are decedents") ///
      legend(off) ///
      scheme(s1mono)
    graph export ../output/figures/mortality_by_phat_`s'.pdf, replace
    label var mort "Mortality"
    label var phat "Phat"
    export excel mort phat using ../../Liran/exhibits.xls, ///
      sheetmodify sheet("E#B4") firstrow(varlabels)
end

* EXECUTE
main
