version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    foreach s in jan {
            build_patient_sample `s'
            clean_patient_sample `s'
        foreach phat in phat phat_lambda {
            compute_patient_ratios `s' `phat'
        }
    }
end

program build_patient_sample
    args s
    use ../external/test_samples/`s'_sample, clear
    merge 1:1 bene_id using ../external/`s'_pmt/spending_backfilled_h365_`s'08, ///
      assert(3) keep(3) keepusing(*_pmt_amt_backfilled *_pmt_amt) nogen
    merge 1:1 bene_id using ../external/`s'_util/ip_visits_days_prcdrs_backfilled_h365_y2008, ///
      assert(3) keep(3) keepusing(num_visits*) nogen
    save ../temp/`s'_merged, replace
end

program clean_patient_sample
    args s
    use ../temp/`s'_merged, clear
    foreach var of varlist * {
        if strpos("`var'","_backfilled") > 0 {
            local new_name = substr("`var'", 1, strpos("`var'","_backfilled"))
            rename `var' `new_name'bf
        }
    }
    gen surv = !mort
    gen dec = mort
    gen phat_lambda = 0.9 * phat + 0.1 * mort
    gen rounded_phat = round(phat,0.01)
    gen rounded_phat_lambda = round(phat_lambda,0.01)
    foreach t in phat phat_lambda {
        egen count_surv_`t' = sum(surv), by(rounded_`t')
        egen count_dec_`t' = sum(dec), by(rounded_`t')
        gen weight_surv_`t' = count_dec_`t' / count_surv_`t'
        gen weight_dec_`t' = count_surv_`t' / count_dec_`t'
    }
    save ../temp/`s'_cleaned_patient, replace
end

program compute_patient_ratios
    args s phat
    use ../temp/`s'_cleaned_patient, clear
    cap matrix drop `s'_ex_ante
    foreach var of varlist tot_pmt_amt op_pmt_amt ip_pmt_amt num_visits {
        compute_differences `var' `s' `phat'
    }
    matrix_to_txt, saving(../output/tables/`s'_ex_ante.txt) ///
      mat(`s'_ex_ante) format(%20.4f) ///
      title(<tab:`s'_ex_ante>) replace
    clear
    svmat `s'_ex_ante
    label var `s'_ex_ante1 "Unweighted Survivors"
    label var `s'_ex_ante2 "Re-weighted Survivors"
    label var `s'_ex_ante3 "Decedents"
    label var `s'_ex_ante4 "Decedents Backfilled"
    if "`s'"=="jan" & "`phat'"=="phat" {
        export excel jan_ex_ante* using ../../Liran/exhibits.xls, ///
          sheetmodify sheet("E#D1") firstrow(varlabels)
    }
    if "`s'"=="jan" & "`phat'"=="phat_lambda" {
        export excel jan_ex_ante* using ../../Liran/exhibits.xls, ///
          sheetmodify sheet("E#D1 with lambda=0.1") firstrow(varlabels)
    }
end

program compute_differences
    args var s phat
    sum `var' if surv
    scalar surv_uw = r(mean)
    sum `var' if dec
    scalar dec_uw = r(mean)
    sum `var' [aw=weight_surv_`phat'] if surv
    scalar surv_w = r(mean)
    sum `var'_bf if dec
    scalar dec_bf = r(mean)
    scalar diff_uw = surv_uw - dec_bf
    scalar diff_w = surv_w - dec_bf
    matrix row`l' = surv_uw, surv_w, dec_uw, dec_bf
    matrix `s'_ex_ante = nullmat(`s'_ex_ante) \ row`l'
end

* EXECUTE
main
