rm(list=ls())
library(randomForest)
library(foreign)
library(doMC)
registerDoMC()

dta <-read.dta("../external_links/event/allfolds.dta")
y <- dta$mort
x <- subset(dta, select = -c(bene_id, mort))

set.seed(1)
# i should have used set.seed(1, "L'Ecuyer-CMRG")

rf <- foreach(ntree=rep(25, 10), .combine=combine, .multicombine=TRUE,
    .packages='randomForest') %dopar% {
    randomForest(x=x,
    y=y, ntree=ntree, mtry=500, nodesize=50, samplesize=50000)
}

save(rf, file="../output/rf.RData")

myTestPred <- function(file, newfile) {
    load("../output/rf.RData")
    test <- read.dta(file)
    ytest <- test$mort
    btest <- test$bene_id
    xtest <- subset(test, select = -c(bene_id, mort))
    pred <- predict(rf, newdata=xtest)
    pred.mort <- data.frame(bene_id = btest, phat = pred, mort = ytest)
    newfile.csv <- paste(newfile, ".csv", sep="")
    write.csv(pred.mort, file=newfile.csv, row.names=FALSE)
}

myTestPred("../external_links/event/test.dta", "../output/rf-test")
myTestPred("../temp/ensemble-b-fit-sample.dta", "../output/rf-ensemble-b-fit")
myTestPred("../temp/calibrate-balanced.dta", "../output/rf-calibrate-balanced")
