version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries
set maxvar 32767, perm
set emptycells drop, perm
set matsize 11000, perm

program main 
    append_phats
    ensemble_coefs
    fit_ensemble
    fit_calibration_ensemble
end

program append_phats 
    forvalues d = 1/10 {
        insheet using ../output/rf_pred`d'.csv, clear
	tempfile rf`d'
	save `rf`d''
	insheet using ../output/glmnet_pred`d'.csv, clear
	tempfile glm`d'
	save `glm`d''
	insheet using ../output/xgboost_pred`d'.csv, clear
	tempfile xgb`d'
	save `xgb`d''
    }
    clear
    forvalues d = 1/10 {
	append using `rf`d''
	drop v1
    }
    ren phat phat_rf
    save ../output/rf, replace
    clear 
    forvalues d = 1/10 {
	append using `glm`d''
    }
    ren phat phat_glm
    save ../output/glm, replace
    clear
    forvalues d = 1/10 {
	append using `xgb`d''
    }
    ren phat phat_xgb
    save ../output/xgb, replace
end

program ensemble_coefs
    foreach m in rf glm xgb {
        insheet using ../output/`m'-ensemble-b-fit.csv, clear
        ren phat phat_`m'
        tempfile `m'
        save ``m''
    }
    clear
    use `rf', clear
    merge 1:1 bene_id using `glm', ///
        assert(3) keepusing(phat_glm) nogen
    merge 1:1 bene_id using `xgb', ///
        assert(3) keepusing(phat_xgb) nogen
    reg mort phat*, nocons
    estimates save ../output/ensemble_coefs.ster, replace
end

program fit_ensemble
    use ../output/rf, clear
    merge 1:1 bene_id using ../output/glm, ///
        assert(3) keepusing(phat_glm) nogen
    merge 1:1 bene_id using ../output/xgb, ///
        assert(3) keepusing(phat_xgb) nogen
    predict phat_ensemble, xb
    save ../output/phats_ensemble, replace
end

program fit_calibration_ensemble
    foreach m in rf glm xgb {
        insheet using ../output/`m'-calibrate-balanced.csv, clear
        ren phat phat_`m'
        tempfile `m'
        save ``m''
    }
    clear
    use `rf', clear
    merge 1:1 bene_id using `glm', ///
        assert(3) keepusing(phat_glm) nogen
    merge 1:1 bene_id using `xgb', ///
        assert(3) keepusing(phat_xgb) nogen
    predict phat_ensemble, xb
    save ../output/phats_ensemble_calibrate_balanced, replace
end

*EXECUTE
main
