#!/usr/bin/env Rscript
rm(list=ls())
library("foreign")
library("randomForest")
library("doMC")
registerDoMC()

args = commandArgs(trailingOnly = "TRUE")
a1 <- args[1]
m <- as.numeric(args[2])
n <- as.numeric(args[3])
s <- as.numeric(args[4])
dta <- read.dta(paste("../external_links/jan/", a1, ".dta", sep=""))

set.seed(1)
# i should have used set.seed(1, "L'Ecuyer-CMRG")

ptm <- proc.time()
rf <- foreach(ntree=rep(50, 5), .combine=combine, .multicombine=TRUE,
    .packages='randomForest') %dopar% {
    randomForest(x=dta[,-which(names(dta) %in% c("bene_id", "mort"))], 
    y=dta$mort, ntree=ntree, mtry=m, nodesize=n, samplesize=s)
}
time.to.run <- proc.time() - ptm
    
loopname <- paste(a1, m, n, s, sep="_")
rdata <- paste("../output/rf_", loopname, ".RData", sep="")
save(rf,time.to.run,file=rdata)

