version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    foreach s in jan event {
        build_data `s'
        clean_data `s'
    }
end

program build_data
    args s
    use ../external/test_samples/`s'_sample, clear
    merge 1:1 bene_id using ../external/`s'_pmt/spending_backfilled_h365_`s'08, ///
      assert(3) keep(3) keepusing(tot_pmt_amt*) nogen
    sum tot_pmt_amt
    global total_spending = r(sum)
    sum tot_pmt_amt_backfilled
    global total_spending_bf = r(sum)
    gen phat_lambda = 0.9 * phat + 0.1 * mort365
    save ../temp/built_`s', replace
end

program clean_data
    args s
    foreach phat in phat phat_lambda {
    use ../temp/built_`s', clear
    gen rounded_phat = round(`phat', 0.01)
    gen phat_bins = rounded_phat

    preserve
    collapse (sum) tot_pmt_amt tot_pmt_amt_backfilled, by(phat_bins)
    gen tot_pmt_amt_share = tot_pmt_amt / $total_spending
    gen tot_pmt_amt_bf_share = tot_pmt_amt_backfilled / $total_spending_bf
    gsort - phat_bins
    gen share_of_total_spending = sum(tot_pmt_amt_share)
    gen share_of_total_spending_bf = sum(tot_pmt_amt_bf_share)
    keep share_of_total_spending* phat_bins
    save ../temp/all, replace
    restore

    collapse (sum) tot_pmt_amt tot_pmt_amt_backfilled, by(phat_bins mort365)
    gen tot_pmt_amt_share = tot_pmt_amt / $total_spending
    gen tot_pmt_amt_bf_share = tot_pmt_amt_backfilled / $total_spending_bf
    preserve
    keep if mort365==1
    gsort - phat_bins
    gen share_of_total_spending_dec = sum(tot_pmt_amt_share)
    gen share_of_total_spending_bf_dec = sum(tot_pmt_amt_bf_share)
    keep share_of_total_spending* phat_bins
    save ../temp/decedents, replace
    restore

    keep if mort365==0
    gsort - phat_bins
    gen share_of_total_spending_surv = sum(tot_pmt_amt_share)
    gen share_of_total_spending_bf_surv = sum(tot_pmt_amt_bf_share)
    keep share_of_total_spending* phat_bins
    merge 1:1 phat_bins using ../temp/decedents, assert(1 2 3) keep(1 2 3) keepusing(*_dec) nogen
    merge 1:1 phat_bins using ../temp/all, assert(1 2 3) keep(1 2 3) keepusing(*) nogen
    save ../temp/merged, replace

    keep phat_bins share_of_total_spending share_of_total_spending_bf ///
      share_of_total_spending_surv share_of_total_spending_bf_surv ///
      share_of_total_spending_dec share_of_total_spending_bf_dec

    label var phat_bins "Phat"
    label var share_of_total_spending "Share of total spending on patients with phat > x"
    label var share_of_total_spending_bf "Share of total backfilled spending on patients with phat > x"
    label var share_of_total_spending_surv "Share of total spending on survivors with phat > x"
    label var share_of_total_spending_bf_surv "Share of total backfilled spending on survivors with phat > x"
    label var share_of_total_spending_dec "Share of total spending on decedents with phat > x"
    label var share_of_total_spending_bf_dec "Share of total backfilled spending on decedents with phat > x"

    if "`phat'"=="phat_lambda" local sheet "E#E1"
    if "`phat'"=="phat" local sheet "E#3"

    if "`s'"=="jan" {
        export excel phat_bins share_of_total_spending share_of_total_spending_bf ///
          share_of_total_spending_surv share_of_total_spending_bf_surv ///
          share_of_total_spending_dec share_of_total_spending_bf_dec ///
          using ../../Liran/exhibits.xls, sheetmodify sheet(`sheet') firstrow(varlabels)
    }

    if "`s'"=="event" & "`phat'"=="phat" {
        export excel phat_bins share_of_total_spending share_of_total_spending_bf ///
          share_of_total_spending_surv share_of_total_spending_bf_surv ///
          share_of_total_spending_dec share_of_total_spending_bf_dec ///
          using ../../Liran/exhibits.xls, sheetmodify sheet("E#C5") firstrow(varlabels)
    }
    }
end

program plot_data
    args i
    use ../temp/merged`i', clear
    foreach b in "" "_bf" {
        foreach p in 91 96 {
            sum share_of_total_spending`b' if mort365==1 & phat_bins==`p'
            local dec`p' = r(mean) * 100
            if `dec`p''==. {
                local dec`p' = 0
            }
            sum share_of_total_spending`b' if mort365==0 & phat_bins==`p'
            local surv`p' = r(mean) * 100
            if `dec`p''==. {
                local dec`p' = 0
            }
            *sum share_of_total_spending`b' if mort365==2 & phat_bins==`p'
            *local all`p' = r(mean) * 100
        }
        keep if phat_bins > 90
        twoway (scatter share_of_total_spending`b' avg_phat if mort365==1) ///
          (scatter share_of_total_spending`b' avg_phat if mort365==0), ///
          legend(order(1 "Decedents" 2 "Survivors")) xtitle("Phat Percentile") ///
          ytitle("Share of total spending on" "patients with phat percentile > x") ///
          xscale(reverse range(0.1 0.6)) ///
          yscale(range(0.0 0.25)) ///
          xlab(0.1 0.2 0.3 0.4 0.5 0.6) ///
          ylab(0.0 0.05 0.1 0.15 0.20 0.25) ///
          note("90th Percentile (decedents): `: di %6.2f `dec91''%" ///
          "90th Percentile (survivors):   `: di %6.2f `surv91''%" ///
          "95th Percentile (decedents): `: di %6.2f `dec96''%" ///
          "95th Percentile (survivors):   `: di %6.2f `surv96''%")
        graph export ../output/figures/spending`b'`i'.pdf, replace
    }
end

* EXECUTE
main
