version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    foreach s in jan event {
        make_sample `s'
        clean_vars `s'
        foreach c in base {
            spend_by_phat `s' `c'
            spend_by_phat_surv_dec_d `s' `c'
        }
    }
    spend_by_phat_old_young
end

program make_sample
    args s
    use ../external/test_samples/`s'_sample.dta, clear
    if "`s'"=="jan" {
        merge 1:1 bene_id using ../external/backfill/other_backfill.dta, ///
          assert(3) keep(3) keepusing(tot_pmt_*) nogen
    }
    if "`s'"=="event" {
        gen tot_pmt_backfilled_a = 0
        gen tot_pmt_backfilled_b = 0
        gen tot_pmt_backfilled_c = 0
    }
    merge 1:1 bene_id using ../external/`s'_pmt/spending_backfilled_h365_`s'08, ///
      assert(3) keep(3) keepusing(tot_pmt_amt*) nogen
    save ../temp/`s'_merged, replace
end

program clean_vars
    args s
    use ../temp/`s'_merged, clear
    gen base = 1
    gen old = age > 85
    gen young = !old
    gen surv = !mort365
    gen dec = mort365
    gen surv_dec = surv | dec
    gen tot_pmt_amt_bf_o = tot_pmt_amt_backfilled
    rename tot_pmt_amt_backfilled tot_pmt_amt_bf
    rename tot_pmt_backfilled_a tot_pmt_amt_bf_a
    rename tot_pmt_backfilled_b tot_pmt_amt_bf_b
    rename tot_pmt_backfilled_c tot_pmt_amt_bf_c
    gen rounded_phat = round(phat, 0.01)
    gen n = 1
    save ../temp/`s'_cleaned, replace
end

program spend_by_phat
    args s c
    use ../temp/`s'_cleaned, clear
    keep if `c'
    collapse (mean) tot_pmt_amt (sum) n, by(rounded_phat)
    rename tot_pmt_amt tot_pmt_amt_all
    rename n n_all
    save ../temp/all, replace

    use ../temp/`s'_cleaned, clear
    keep if `c'
    keep if mort365
    collapse (mean) tot_pmt_amt* (sum) n, by(rounded_phat)
    rename tot_pmt_amt tot_pmt_amt_dec
    rename tot_pmt_amt_bf tot_pmt_amt_bf_dec
    rename n n_dec
    save ../temp/dec, replace

    use ../temp/`s'_cleaned, clear
    keep if `c'
    keep if !mort365
    collapse (mean) tot_pmt_amt (sum) n, by(rounded_phat)
    rename tot_pmt_amt tot_pmt_amt_surv
    rename n n_surv

    merge 1:1 rounded_phat using ../temp/dec, nogen
    merge 1:1 rounded_phat using ../temp/all, nogen

    label var rounded_phat "Phat"
    label var n_all "Patients"
    label var n_surv "Survivors"
    label var n_dec "Decedents"
    label var tot_pmt_amt_all "Average spending"

    if "`s'"=="jan" {
        export excel rounded_phat n_* tot_pmt_amt_all using ../../Liran/exhibits.xls, ///
          sheetmodify sheet("E#2") firstrow(varlabels)
    }
    if "`s'"=="event" {
        export excel rounded_phat n_* tot_pmt_amt_all using ../../Liran/exhibits.xls, ///
          sheetmodify sheet("E#C4") firstrow(varlabels)
    }
end

program spend_by_phat_surv_dec_d
    args s c
    use ../temp/`s'_cleaned, clear
    keep if `c'
    append using ../external/phat_grids/`s'_grid
    foreach m in surv dec {
        lpoly tot_pmt_amt phat if `m', at(phat_grid) ///
          gen(x1_`m' tot_pmt_amt_lp_`m')
        if "`m'"=="dec" {
            foreach l in o a b c {
                lpoly tot_pmt_amt_bf_`l' phat if `m', at(phat_grid) ///
                  gen(x2_`m' tot_pmt_amt_bf_`l'_lp_`m')
                drop x2_`m'

            }
        }
        kdensity phat if `m', at(phat_grid) gen(phat_predict_kd_`m' density_kd_`m')
    }
    keep if phat_grid != . & phat_grid > 0.0001
    label var phat_grid "Phat"
    label var tot_pmt_amt_lp_surv "Avg Spending (survivors)"
    label var tot_pmt_amt_lp_dec "Avg Spending (decedents)"
    label var tot_pmt_amt_bf_o_lp_dec "Avg Spending (decedents, backfilled)"
    label var density_kd_surv "Kernel density, survivors"
    label var density_kd_dec "Kernel density, decedents"

    if "`s'"=="jan" {
        export excel phat_grid tot_pmt_amt_lp_surv tot_pmt_amt_lp_dec tot_pmt_amt_bf_o_lp_dec ///
          density_kd_surv density_kd_dec ///
          using ../../Liran/exhibits.xls, sheetmodify sheet("E#4") firstrow(varlabels)
     }
    if "`s'"=="event" {
        export excel phat_grid tot_pmt_amt_lp_surv tot_pmt_amt_lp_dec tot_pmt_amt_bf_o_lp_dec ///
          density_kd_surv density_kd_dec ///
          using ../../Liran/exhibits.xls, sheetmodify sheet("E#C6") firstrow(varlabels)
     }

    label var tot_pmt_amt_bf_o_lp_dec "Backfilled"
    label var tot_pmt_amt_bf_a_lp_dec "Backfilled with avg spending for patients who die in same month"
    label var tot_pmt_amt_bf_b_lp_dec "Backfilled with avg spending for decedents"
    label var tot_pmt_amt_bf_c_lp_dec "Backfilled with avg 2007 patient spending"

    if "`s'"=="jan" {
        export excel phat_grid tot_pmt_amt_lp_surv tot_pmt_amt_lp_dec ///
          tot_pmt_amt_bf_o_lp_dec tot_pmt_amt_bf_a_lp_dec tot_pmt_amt_bf_b_lp_dec ///
          tot_pmt_amt_bf_c_lp_dec ///
          using ../../Liran/exhibits.xls, sheetmodify sheet("E#R1") firstrow(varlabels)
    }
end

program spend_by_phat_old_young
    foreach age in young old {
        use ../temp/jan_cleaned, clear
        keep if `age'
        append using ../external/phat_grids/jan_grid
        foreach m in surv dec {
            lpoly tot_pmt_amt phat if `m', at(phat_grid) ///
              gen(x1_`m' tot_pmt_amt_lp_`m')
            lpoly tot_pmt_amt_bf_o phat if `m', at(phat_grid) ///
              gen(x2_`m' tot_pmt_amt_bf_lp_`m')
            kdensity phat if `m', at(phat_grid) gen(phat_predict_kd_`m' density_kd_`m')
        }
        keep if phat_grid != . & phat_grid > 0.0001
        foreach var of varlist tot_pmt_amt_lp_surv tot_pmt_amt_lp_dec tot_pmt_amt_bf_lp_dec {
            rename `var' `var'_`age'
        }
        save ../temp/`age', replace
    }
    use ../temp/old, clear
    merge 1:1 phat_grid using ../temp/young, nogen
    label var phat_grid "Phat"
    label var tot_pmt_amt_lp_surv_old "Avg Spending (survivors, 85+)"
    label var tot_pmt_amt_lp_dec_old "Avg Spending (decedents, 85+)"
    label var tot_pmt_amt_bf_lp_dec_old "Avg Spending (decedents, backfilled, 85+)"

    label var tot_pmt_amt_lp_surv_young "Avg Spending (survivors, <85)"
    label var tot_pmt_amt_lp_dec_young "Avg Spending (decedents, <85)"
    label var tot_pmt_amt_bf_lp_dec_young "Avg Spending (decedents, backfilled, <85)"

    export excel phat_grid tot_pmt_amt_lp_surv_old tot_pmt_amt_lp_dec_old tot_pmt_amt_bf_lp_dec_old ///
      tot_pmt_amt_lp_surv_young tot_pmt_amt_lp_dec_young tot_pmt_amt_bf_lp_dec_young ///
      using ../../Liran/exhibits.xls, sheetmodify sheet("E#R3") firstrow(varlabels)
end

* EXECUTE
main
