version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    foreach s in event jan {
        clean_pmt `s'
        make_sample `s'
        compute_shares `s'
    }
end

program clean_pmt
    args s
    foreach h in 7 30 90 365 {
        use bene_id tot_pmt_amt tot_pmt_amt_backfilled ///
          using ../external/`s'_pmt/spending_backfilled_h`h'_`s'08, clear
        rename tot_pmt_amt tot_pmt_amt`h'
        rename tot_pmt_amt_backfilled tot_pmt_amt_b`h'
        save ../temp/`s'_pmt`h', replace
    }
    use ../temp/`s'_pmt7, clear
    foreach h in 30 90 365 {
        merge 1:1 bene_id using ../temp/`s'_pmt`h', ///
          assert(3) keep(3) keepusing(tot_pmt_amt*) nogen
    }
    save ../temp/`s'_pmt, replace
end

program make_sample
   args s
   if "`s'"=="jan" use ../external_links/jan/1jan2008, clear
   if "`s'"=="event" use ../external_links/event/event2008, clear
   merge 1:1 bene_id using ../temp/`s'_pmt, assert(3) keep(3) keepusing(tot_pmt_amt*) nogen
   capture gen mort7 = days_t0_to_death < 7
   save ../temp/`s'_merged, replace
end

program compute_shares
    args s
    use ../temp/`s'_merged, clear
    foreach h in 7 30 90 365 {
        sum tot_pmt_amt`h'
        scalar total_spending = r(sum)
        sum tot_pmt_amt`h' if mort`h'
        scalar dec_spending = r(sum)
        scalar dec_spending_share`h' = dec_spending / total_spending
        sum tot_pmt_amt_b`h'
        scalar total_spending_b = r(sum)
        sum tot_pmt_amt_b`h' if mort`h'
        scalar dec_spending_b = r(sum)
        scalar dec_spending_b_share`h' = dec_spending_b / total_spending_b
        sum mort`h'
        scalar dec_share`h' = r(mean)
        matrix `s'_shares = nullmat(`s'_shares) \ ///
          (dec_spending_share`h', dec_spending_b_share`h', dec_share`h')
    }
    clear
    svmat `s'_shares
    rename `s'_shares1 dec_spending_share
    rename `s'_shares2 dec_spending_b_share
    rename `s'_shares3 dec_share
    if "`s'"=="jan" {
        gen label = "Jan. 7" if _n==1
        replace label = "Jan. 31" if _n==2
        replace label = "March 31" if _n==3
        replace label = "Dec. 31" if _n==4
    }
    else {
        gen label = "7 Days" if _n==1
        replace label = "30 Days" if _n==2
        replace label = "90 Days" if _n==3
        replace label = "365 Days" if _n==4
    }
    save ../temp/`s'_to_plot, replace
    label var dec_share "Mortality Rate"
    label var dec_spending_share "Share of spending on decedents"
    label var dec_spending_b_share "Share of backfilled spending on dec"
    label var label "Horizon"

    if "`s'"=="jan" {
        export excel dec_share dec_spending_share dec_spending_b_share label using ///
          ../../Liran/exhibits.xls, sheetmodify sheet("E#1") firstrow(varlabels)
    }

    if "`s'"=="event" {
        export excel dec_share dec_spending_share dec_spending_b_share label using ///
          ../../Liran/exhibits.xls, sheetmodify sheet("E#C3") firstrow(varlabels)
    }
end

* EXECUTE
main
