version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    foreach s in event jan {
        prepare_visits_and_spending `s'
        make_sample `s'
        clean_vars `s'
        make_sum_stats `s'
    }
end

program prepare_visits_and_spending
    args s
    use ../external/`s'_visits_days_prcdrs/ip_visits_days_prcdrs365_08.dta, clear
    rename num_visits num_ip_visits
    keep bene_id num_ip_visits num_ip_days num_prcdrs num_ip_er_visits
    foreach var of varlist num_* {
        rename `var' `var'_08
    }
    save ../temp/`s'_ip_visits_days_prcdrs_08, replace

    use ../external/`s'_visits_days_prcdrs/op_er_visits365_08.dta, clear
    rename num_op_er_visits num_op_er_visits_08
    save ../temp/`s'_op_er_visits_08, replace

    use ../external/`s'_pmt/spending_backfilled_h365_`s'08, clear
    keep bene_id tot_pmt_amt
    rename tot_pmt_amt spending_08
    save ../temp/`s'_spending_08, replace

    use ../external/`s'_util/prior_pmt_y08, clear
    keep bene_id tot_pmt_amt
    rename tot_pmt_amt spending_07
    save ../temp/`s'_spending_07, replace

    use ../external/`s'_util/prior_ip_y08, clear
    keep bene_id num_ip_visits* num_ip_days* num_prcdr* num_ip_er_visits*
    foreach var in num_ip_visits num_ip_days num_prcdrs num_ip_er_visits {
        if "`s'"=="event" gen `var'_07 = `var'_m13 + `var'_m36 + `var'_m69 + `var'_m912
        if "`s'"=="jan" gen `var'_07 = `var'_m13 + `var'_m36 + `var'_m69 + `var'_m912
    }
    save ../temp/`s'_ip_visits_days_prcdrs_07, replace
end

program make_sample
    args s
    if "`s'"=="jan" local s_name 1jan
    if "`s'"=="event" local s_name `s'
    use ../external_links/`s'/`s_name'2008.dta, clear
    merge 1:1 bene_id using ../external/`s'_hcc/HCC_y08.dta, ///
      assert(3) keep(3) keepusing(score_community) nogen
    foreach year in 07 08 {
        merge 1:1 bene_id using ../temp/`s'_ip_visits_days_prcdrs_`year'.dta, ///
          assert(1 2 3) keep(3) keepusing(num_*) nogen
        merge 1:1 bene_id using ../temp/`s'_spending_`year'.dta, ///
          assert(1 3) keep(3) keepusing(spending_`year') nogen
    }
    merge 1:1 bene_id using ../external/`s'_mort_yr/yearly_mortality.dta, ///
      assert(3) keep(3) keepusing(mort_y3 mort_y5) nogen
    save ../temp/`s'_merged, replace
end

program clean_vars
    args s
    use ../temp/`s'_merged, clear
    rename score_community hcc
    rename sex female
    rename race white
    gen all = 1
    gen surv = !mort365
    gen dec = mort365
    foreach year in 07 08 {
        replace num_ip_er_visits_`year' = 0 if num_ip_er_visits_`year'==.
        replace num_ip_visits_`year' = 0 if num_ip_visits_`year'==.
        gen num_admsns_`year' = num_ip_visits_`year'
        gen has_admsn_`year' = num_admsns_`year' > 0
        gen has_prcdr_`year' = num_prcdrs_`year' > 0
    }
    save ../temp/`s'_cleaned, replace
end

program make_sum_stats
    args s
    global statistics female white age mort30 mort365 mort_y5 spending_07 has_admsn_07
    foreach type in all surv dec {
        use ../temp/`s'_cleaned, clear
        keep if `type'
        foreach stat in $statistics {
            sum `stat'
            matrix `s'_`type'_col = nullmat(`s'_`type'_col) \ r(mean)
        }
        count
        matrix `s'_`type'_col = nullmat(`s'_`type'_col) \ r(N)
        matrix `s'_sum_stats = nullmat(`s'_sum_stats), `s'_`type'_col
    }
    matrix_to_txt, saving(../output/tables/`s'_sum_stats.txt) ///
      mat(`s'_sum_stats) format(%20.4f) ///
      title(<tab:`s'_sum_stats>) replace
    clear
    svmat `s'_sum_stats
    label var `s'_sum_stats1 "Full Sample"
    label var `s'_sum_stats2 "Survivors"
    label var `s'_sum_stats3 "Decedents"
    if "`s'"=="jan" export excel using ../../Liran/exhibits.xls, ///
      sheetmodify sheet("E#A1") firstrow(varlabels)
    if "`s'"=="event" export excel using ../../Liran/exhibits.xls, ///
      sheetmodify sheet("E#C1") firstrow(varlabels)
end

* EXECUTE
main
