version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries
set varabbrev off
set maxvar 32000

program main 
    data
    def_groups
    regs
end

program data
    insheet using ../external/rf/bc_phats_test.csv, clear
    merge 1:1 bene_id using ../external_links/jan/test, ///
        assert(3) nogen
    ren *zc* zc**
    drop bene_id mort
    compress
    save ../temp/data, replace
end

program def_groups
    global demo "age race sex mcaid hrr*"
    global gagne "m01* m03* m36* m69* m912* d01* d03* d07*"
    global zc "zc*"
    global chronic "ami-hypoth"
    global util "num_* primary* specialist* score_community"
    global pmt "tot_* ip_* op_*"
end

program regs
    mat def r2 = J(7,5,.)
    local r = 1
    foreach x in demo gagne zc chronic util pmt {
        use ../temp/data, clear
        order phat
        drop $`x'
        qui reg *
        mat def r2[`r', 2] = e(r2)
        mat def r2[`r', 3] = e(r2_a)
        di "`x': `e(r2)' `e(r2_a)'"
        local r = `r' + 1
    }
    use ../temp/data, clear
    order phat
    reg *
    mat def r2[`r', 2] = e(r2)
    mat def r2[`r', 3] = e(r2_a)
    local r = 1
    foreach x in demo gagne zc chronic util pmt {
        di "`x'"
        qui reg phat $`x'
        mat def r2[`r', 4] = e(r2)
        mat def r2[`r', 5] = e(r2_a)
        di "`x': `e(r2)' `e(r2_a)'"
        local r = `r' + 1
    }
    local r = 1
    foreach x in demo gagne zc chronic util pmt {
        use in 1 using ../temp/data, clear
        keep $`x'
        qui d 
        mat def r2[`r', 1] = r(k)
        local r = `r' + 1
    }
    clear
    svmat r2
    ren (r21 r22 r23 r24 r25) (nvar r2_excl ar2_exc r2_inc ar2_inc)
    drop ar2*
    gen group = ""
    local r = 1
    foreach x in demo gagne zc chronic util pmt none {
        replace group = "`x'" in `r'
        local r = `r' + 1
    }
    order group nvar r2_inc r2_excl
    export excel * using ../../Liran/exhibits.xls, ///
        sheetmodify sheet("E#B6") firstrow(var)
end

*EXECUTE
main 

