version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    set matsize 11000, perm
    import_data
    code_to_label_xwalk
    one_code
    has_T
    expand_no_T
    expand_T
    append_xwalk
end

program import_data
    import delimited 2017_ccs_services_procedures.csv, delim(",")
    keep if _n > 2
    rename v1 code_range
    rename v2 ccs_code
    rename v3 ccs_lab
    save ../temp/imported, replace
end

program code_to_label_xwalk
    use ../temp/imported, clear
    destring ccs_code, replace
    collapse (first) ccs_lab, by(ccs_code)
    save ../temp/code_to_label_xwalk, replace
end

program one_code
    use ../temp/imported, clear
    gen code1 = substr(code_range,2,5)
    gen code2 = substr(code_range,8,5)
    destring ccs_code, replace
    preserve
    keep if code1==code2
    rename code1 hcpcs_cd
    keep ccs_code hcpcs_cd
    tostring hcpcs_cd, replace
    save ../temp/one_code, replace
    restore
    drop if code1==code2
    save ../temp/range_of_codes, replace
end

program has_T
    use ../temp/range_of_codes, clear
    preserve
    keep if strpos(code_range,"T")
    save ../temp/range_of_codes_T, replace
    restore
    drop if strpos(code_range,"T")
    save ../temp/range_of_codes_no_T, replace
end

program expand_no_T
    use ../temp/range_of_codes_no_T, clear
    destring code1 code2, replace
    count
    local N = r(N)
    scalar j = 0
    local mat_num = 1
    forvalues i = 1/`N' {
        preserve
        keep if _n==`i'
        display "`i'"
        display j
        while code1[1]<=code2[1] {
            if j==1000 {
                scalar j = 0
                local mat_num = `mat_num' + 1
            }
            matrix xwalk_no_t`mat_num' = nullmat(xwalk_no_t`mat_num') \ (code1[1], ccs_code[1])
            replace code1 = code1 + 1
            scalar j = j + 1
        }
        restore
    }
    forvalues i = 1/`mat_num' {
        clear
        svmat xwalk_no_t`i'
        rename xwalk_no_t`i'1 hcpcs_cd
        rename xwalk_no_t`i'2 ccs_code
        tostring hcpcs_cd, replace
        save ../temp/hcpcs_cd_no_T`i', replace
    }
    use ../temp/hcpcs_cd_no_T1, clear
    forvalues i = 2/`mat_num' {
        append using ../temp/hcpcs_cd_no_T`i'
    }
    save ../temp/hcpcs_cd_no_T, replace
end

program expand_T
    use ../temp/range_of_codes_T, clear
    replace code1 = substr(code1,1,4)
    replace code2 = substr(code2,1,4)
    destring code1 code2, replace
    count
    local N = r(N)
    forvalues i = 1/`N' {
        preserve
        keep if _n==`i'
        while code1[1]<=code2[1] {
            matrix xwalk_t = nullmat(xwalk_t) \ (code1[1], ccs_code[1])
            replace code1 = code1 + 1
        }
        restore
    }
    clear
    svmat xwalk_t
    rename xwalk_t1 hcpcs_cd
    rename xwalk_t2 ccs_code
    tostring hcpcs_cd, replace
    replace hcpcs_cd = hcpcs_cd + "T"
    save ../temp/hcpcs_cd_T, replace
end

program append_xwalk
    use ../temp/one_code, clear
    append using ../temp/hcpcs_cd_no_T
    append using ../temp/hcpcs_cd_T
    merge m:1 ccs_code using ../temp/code_to_label_xwalk, ///
      assert(1 2 3) keep(1 2 3) keepusing(*) nogen
    save ../output/procedure_xwalk, replace
end

* EXECUTE
main
