version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

global ipc_07 "../external/ip_cleaned/ip_visits_2007.dta"
global ipc_08 "../external/ip_cleaned/ip_visits_2008.dta"
global ipc_09 "../external/ip_cleaned/ip_visits_2009.dta"

program main
    foreach year in "07" "08" "09" {
        prepare_ip `year'
    }
    calc_horizon 08 09
end

program prepare_ip
    args year
    use ${ipc_`year'}, clear
    merge m:1 bene_id using ../external_links/event/event2008.dta, ///
      assert(master using match) keep(match) keepusing(sdod t0) nogen
    save ../temp/ip_event_`year'.dta, replace
end

program calc_horizon
    args y1 y2
    use ../temp/ip_event_`y1', clear
    append using ../temp/ip_event_`y2'
    foreach h in 7 365 {
        use ../temp/ip_event_`y1'.dta, clear

        gen days_survived = sdod - t0
        gen days_backfill = `h' - days_survived
        keep if admsn_dt >= t0 - days_backfill
        drop if admsn_dt>=t0

        save ../output/backfill_ip_visits`h'_`y1'.dta, replace
        collapse (sum) num_visits num_ip_days num_prcdrs icu_visits=icu, by(bene_id)

        merge m:1 bene_id using ../external_links/event/event2008.dta, ///
          assert(using match) keep(using match) keepusing(bene_id) nogen
        foreach var of varlist num_* icu_visits {
            replace `var' = 0 if mi(`var')
        }
        save_data ../output/backfill_ip_visits_days_prcdrs`h'_`y1'.dta, key(bene_id) replace ///
          log(../output/data_file_manifest.log)
    }
end

* EXECUTE
main
