version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries

program main 
    args y l
    sample `y'
    dgns_var `y'
    ip_last `y' `l'
    op_last `y' `l'
    car_last `y' `l'
    append_claims `y' `l'
    prepare_gagne `y'
    gagne_counts `y'
end 

program sample
    args y
    use bene_id t0 using "../external_links/event/event2008", clear
    save ../temp/sample`y', replace
end

program dgns_var
    args y
    if "`y'" == "08" {
        global dgns dgnscd1
        global cdgns dgns_cd1
    }
    else if "`y'" == "11" {
        global dgns icd_dgns_cd1 
        global cdgns icd_dgns_cd1
        global idgns dgnscd1
    }
end

program ip_last
    args y l
    use ../external/ip_visits/ip_visits_20`l', clear
    append using ../external/ip_visits/ip_visits_20`y'
    save ../temp/ip_visits_`l'_`y', replace
    use ../temp/sample`y', clear
    merge 1:m bene_id using "../temp/ip_visits_`l'_`y'", ///
        assert(1 2 3) keep(3) keepusing(admsn_dt ${idgns}) nogen
    // in 1 if no ip event in last year 
    // in 2 if not in sample 
    duplicates drop
    if "${idgns}" == "dgnscd1" {
        ren dgnscd1 icd_dgns_cd1
    }
    gen diff_date = t0 - admsn_dt
    keep if diff_date > 0 & diff_date <= 365
    save ../temp/ip_dgns`l', replace
end

program op_last
    args y l
    use ../external_links/op`l'/opr20`l', clear
    append using ../external_links/op`y'/opr20`y'
    save ../temp/opr_`l'_`y', replace
    use ../external_links/op`l'/opc20`l', clear
    append using ../external_links/op`y'/opc20`y'
    save ../temp/opc_`l'_`y', replace
    use ../temp/sample`y', clear
    merge 1:m bene_id using ../temp/opr_`l'_`y', ///
        assert(1 2 3) keep(3) keepusing(clm_id rev_dt)
    // in 1 if no op claims in the last year
    // in 2 if not a decedent within horizon 
    collapse (min) rev_dt (first) t0, by(bene_id clm_id)
    merge 1:1 bene_id clm_id using ../temp/opc_`l'_`y', ///
        assert(2 3) keep(3) keepusing(${dgns}) nogen
    gen diff_date = t0 - rev_dt
    keep if diff_date > 0 & diff_date <= 365
    save ../temp/op_dgns`l', replace
end

program car_last
    args y l
    use ../external_links/car`l'/carl20`l', clear
    append using ../external_links/car`y'/carl20`y'
    save ../temp/carl_`l'_`y', replace
    use ../external_links/car`l'/carc20`l', clear
    append using ../external_links/car`y'/carc20`y'
    save ../temp/carc_`l'_`y', replace
    use ../temp/sample`y', clear
    merge 1:m bene_id using ../temp/carl_`l'_`y', ///
        assert(1 2 3) keep(3) keepusing(clm_id expnsdt1) nogen
    // in 1 if no car claims in the last year
    // in 2 if not a decedent within horizon
    collapse (min) expnsdt1 (first) t0, by(bene_id clm_id)
    merge 1:1 bene_id clm_id using ../temp/carc_`l'_`y', ///
        assert(2 3) keep(3) keepusing(${cdgns}) nogen
    if "${cdgns}" == "dgns_cd1" {
        ren dgns_cd1 dgnscd1
    }
    gen diff_date = t0 - expnsdt1
    keep if diff_date > 0 & diff_date <= 365
    save ../temp/car_dgns`l', replace
end

program append_claims
     args y l
     use ../temp/ip_dgns`l'
     append using ../temp/op_dgns`l'
     append using ../temp/car_dgns`l'
     foreach v of varlist admsn_dt rev_dt expnsdt1 {
        replace `v' = 0 if `v'==.
     }
     gen date = admsn_dt + rev_dt + expnsdt1
     format %td date
     drop admsn_dt rev_dt expnsdt1
     save ../temp/appended`y', replace
end

program prepare_gagne
    args y
    use ../temp/appended`y', clear
    ren ${dgns} ICD
    define_gagne
    drop if disease == ""
    bysort bene_id disease date: gen dup = cond(_N==1, 0, _n)
    drop if dup > 1
    drop dup
    save ../temp/gagne`y', replace
end

program gagne_counts
    args y
    use "../temp/gagne`y'", clear
    drop if t0 <= date | t0 - date > 365
    gen m03 = cond(date < t0 & date >= t0 - 90, 1, 0) 
    gen m36 = cond(date < t0 - 90 & date >= t0 - 180, 1, 0) 
    gen m69 = cond(date < t0 - 180 & date >= t0 - 270, 1, 0) 
    gen m912 = cond(date < t0 - 270 & date >= t0 - 365, 1, 0) 
    gen m01 = cond(date < t0 & date >= t0 - 30, 1, 0) 
    gen m112 = cond(date < t0 - 30 & date >= t0 - 365, 1, 0) 
    gen d01 = cond(date < t0 - 0 & date >= t0 - 1, 1, 0) 
    gen d03 = cond(date < t0 - 0 & date >= t0 - 3, 1, 0) 
    gen d07 = cond(date < t0 - 0 & date >= t0 - 7, 1, 0) 
    collapse (sum) m03 m36 m69 m912 m01 m112 d01 d03 d07, by(bene_id disease t0) 
    egen gng = group(disease)
    save ../temp/gn_reshape_ready_`y', replace
    su gng
    global G = r(max)
    foreach h in m03 m36 m69 m912 m01 m112 d01 d03 d07 { 
        use ../temp/gn_reshape_ready_`y', clear
        keep bene_id disease `h'
        reshape wide `h', i(bene_id) j(disease, string)
        save_data ../output/gn_`h'_y`y', key(bene_id) replace
    }
end

program define_gagne
    gen disease  = "metastatic_romano"  if substr(ICD,1,3)  == "196" | substr(ICD,1,3)  == "197" | ///
    substr(ICD,1,3)  == "198" | substr(ICD,1,3)  == "199"
    replace disease  = "chf_romano"  if ICD  == "40201" | ICD  == "40211" | ICD  == "40291" | ///
    substr(ICD,1,4)  == "4293" | substr(ICD,1,3)  == "425" | substr(ICD,1,3)  == "428"
    replace disease  = "dementia_romano"  if substr(ICD,1,4)  == "3310" | substr(ICD,1,4)  == "3311" | ///
    substr(ICD,1,4)  == "3312" | substr(ICD,1,3)  == "290"
    replace disease  = "renal_elixhauser" if ICD  == "40311" | ICD  == "40391" | ICD  == "40412" | ///
    ICD  == "40492" | substr(ICD,1,3)  == "585" | substr(ICD,1,3)  == "586" | substr(ICD,1,4)  == "V420" | ///
    substr(ICD,1,4)  == "V451" | substr(ICD,1,4)  == "V560" | substr(ICD,1,4)  == "V568"
    replace disease  = "wtloss_elixhauser" if  substr(ICD,1,3)=="260" |substr(ICD,1,3)=="261" | ///
    substr(ICD,1,3)=="262"| substr(ICD,1,3)=="263"
    replace disease  = "hemiplegia_romano" if substr(ICD,1,3)  == "342" | substr(ICD,1,3)  == "344"
    replace disease  = "alcohol_elixhauser" if substr(ICD,1,4)  == "2911" | substr(ICD,1,4)  == "2992" | ///
    substr(ICD,1,4)  == "2915" | substr(ICD,1,4)  == "2918" | substr(ICD,1,4)  == "2919"   | ///
    substr(ICD,1,4)  == "V113"
    replace disease  = "alcohol_elixhauser" if ICD>="30390" & ICD < ="30393"
    replace disease  = "alcohol_elixhauser" if  ICD>= "30500" & ICD < = "30503"
    replace disease  = "tumor_romano"  if substr(ICD,1,4)  == "2730"| substr(ICD,1,4)  == "2733" | ///
    substr(ICD,1,5)  == "V1046"
    replace disease  = "tumor_romano" if  substr(ICD,1,3)>="174" & substr(ICD,1,3) < = "195"
    replace disease  = "tumor_romano" if substr(ICD,1,3)>= "200" & substr(ICD,1,3) < = "208"
    replace disease  = "tumor_romano" if substr(ICD,1,3) >="140" & substr(ICD,1,3) < = "171"
    replace disease  = "arrhythmia_elixhauser" if ICD  == "42610" | ICD  == "42611" | ICD  == "42613" | ///
    substr(ICD,1,4)  == "4270" | substr(ICD,1,4)  == "4272" | ICD  == "42731" | ICD  == "42760" | ///
    substr(ICD,1,4)  == "4279" | substr(ICD,1,4)  == "7850" | substr(ICD,1,4)  == "V450" | ///
    substr(ICD,1,4)  == "V533"
    replace disease  = "arrhythmia_elixhauser" if ICD >= "42650" & ICD < ="42653"
    replace disease  = "arrhythmia_elixhauser" if ICD >= "4262"  & substr(ICD,1,4) < = "4264"
    replace disease  = "arrhythmia_elixhauser" if ICD >=  "4266" &  substr(ICD,1,4) < = "4268"
    replace disease  = "pulmonarydz_romano"  if substr(ICD,1,4)  == "4150" | substr(ICD,1,4)  == "4168" | ///
    substr(ICD,1,4)  == "4169" | substr(ICD,1,3)  == "491"  | substr(ICD,1,3)  == "492"  | ///
    substr(ICD,1,3)  == "493"  | substr(ICD,1,3)  == "494"  | substr(ICD,1,3)  == "496"
    replace disease  = "coagulopathy_elixhauser" if substr(ICD,1,4)  == "2871"
    replace disease  = "coagulopathy_elixhauser" if ICD >=  "2860" & substr(ICD,1,4) < = "2869"
    replace disease  = "coagulopathy_elixhauser" if ICD >= "2873" & substr(ICD,1,4) < = "2875"
    replace disease  = "compdiabetes_elixhauser" if ICD >="25040" & ICD < ="25073"
    replace disease  = "compdiabetes_elixhauser" if ICD >= "25090" & ICD < = "25093"
    replace disease  = "anemia_elixhauser" if substr(ICD,1,4)  == "2859"
    replace disease  = "anemia_elixhauser" if ICD >= "2801" & substr(ICD,1,4) < = "2819"
    replace disease  = "electrolytes_elixhauser" if  ICD >= "2760" & substr(ICD,1,4) < = "2769"
    replace disease  = "liver_elixhauser" if ICD  == "07032" | ICD  == "07033" | ICD  == "07054" | ///
    substr(ICD,1,4)  == "4560" | substr(ICD,1,4)  == "4561" | ICD  == "45620" | ICD  == "45621" | ///
    substr(ICD,1,4)  == "5710" | substr(ICD,1,4)  == "5712" |  substr(ICD,1,4)  == "5713" | ///
    substr(ICD,1,4)  == "5715" | substr(ICD,1,4)  == "5716" | substr(ICD,1,4)  == "5718" | ///
    substr(ICD,1,4)  == "5719" | substr(ICD,1,4)  == "5723" | substr(ICD,1,4)  == "5728" | ///
    substr(ICD,1,4)  == "V427"
    replace disease  = "liver_elixhauser" if ICD >="57140"  & ICD < = "57149"
    replace disease  = "pvd_elixhauser" if  substr(ICD,1,4)  == "4412" |substr(ICD,1,4)  == "4414" | ///
    substr(ICD,1,4)  == "4417" | substr(ICD,1,4)  == "4419" | substr(ICD,1,4)  == "4471" | ///
    substr(ICD,1,4)  == "5571" |  substr(ICD,1,4)  == "5579" | substr(ICD,1,4)  == "V434"
    replace disease  = "pvd_elixhauser" if ICD >= "4400" &  substr(ICD,1,4) < = "4409"
    replace disease  = "pvd_elixhauser" if ICD >=  "4431" & substr(ICD,1,4) < = "4439"
    replace disease  = "psychosis_elixhauser" if ICD  == "29910" | ICD  == "29911"
    replace disease  = "psychosis_elixhauser" if  ICD >= "29500" & ICD < = "29899"
    replace disease  = "pulmcirc_elixhauser" if substr(ICD,1,3)  == "416" | substr(ICD,1,4)  == "4179"
    replace disease  = "hivaids_romano" if substr(ICD,1,3)  == "042" | substr(ICD,1,3)  == "043" | ///
    substr(ICD,1,3)  == "044"
    replace disease  = "hypertension_elixhauser" if substr(ICD,1,4)  == "4011" | substr(ICD,1,4)  == "4019" | ///
    ICD  == "40210" | ICD  == "40290" | ICD  == "40410" | ICD  == "40490" | ICD  == "40511" | ///
    ICD  == "40519" | ICD  == "40591" | ICD  == "40599"

    * New Gagne conditions
    replace disease = "mi_romano" if substr(ICD,1,3) == "410" | substr(ICD,1,3) == "412"
    replace disease = "stroke_romano" if ICD == "36234" | substr(ICD,1,3) == "430" | substr(ICD,1,3) == "431" | ///
    substr(ICD,1,3) == "432" | substr(ICD,1,3) == "433" | substr(ICD,1,3) == "434" | substr(ICD,1,3) == "435" | ///
    substr(ICD,1,3) == "436" | substr(ICD,1,4) == "437 " | substr(ICD,1,4) == "4371" | ///
    substr(ICD,1,4) == "4370" | substr(ICD,1,4) == "4379" | substr(ICD,1,3) == "438" | ///
    substr(ICD,1,4) == "7814" | substr(ICD,1,4) == "7843" | substr(ICD,1,4) == "9970"
    replace disease = "rheum_romano" if substr(ICD,1,3) == "710" | substr(ICD,1,3) == "714"
    replace disease = "ulcer_elixhauser" if ICD == "53170" | ICD == "53190" | ICD == "53270" | ///
    ICD == "53290" | ICD == "53370" | ICD == "53390" | ICD == "53470" | ICD == "53490" | ICD == "V1271"
    replace disease = "uncompdiabetes_elixhauser" if ICD >= "25000" & ICD <= "25033"
    replace disease = "valvular_elixhauser" if ICD >= "09320" & ICD <= "09324"
    replace disease = "valvular_elixhauser" if ICD >= "3940" & substr(ICD,1,4) <= "3971"
    replace disease = "valvular_elixhauser" if ICD >= "4240" & substr(ICD,1,4) <= "4248"
    replace disease = "valvular_elixhauser" if ICD == "42490" | ICD == "42491"
    replace disease = "valvular_elixhauser" if ICD >= "7463" & substr(ICD,1,4) <= "7466"
    replace disease = "valvular_elixhauser" if substr(ICD,1,4) == "V422" | substr(ICD,1,4) == "V433"
    replace disease = "thyroid_elixhauser" if substr(ICD,1,3) == "243" | substr(ICD,1,4) == "2448" | ///
    substr(ICD,1,4) == "2449" | substr(ICD,1,4) == "2440" | substr(ICD,1,4) == "2441" | ///
    substr(ICD,1,4) == "2442"
    replace disease = "obesity_elixhauser" if substr(ICD,1,4) == "2780"
    replace disease = "drugs_elixhauser" if substr(ICD,1,4) == "2920" | substr(ICD,1,4) == "2929"
    replace disease = "drugs_elixhauser" if ICD >= "29282" & ICD <= "29289"
    replace disease = "drugs_elixhauser" if ICD >= "30400" & ICD <= "30493"
    replace disease = "drugs_elixhauser" if ICD >= "30520" & ICD <= "30593"
    replace disease = "depression_elixhauser" if substr(ICD,1,4) == "3004" | ICD == "30112" | ///
    substr(ICD,1,4) == "3090" | substr(ICD,1,4) == "3091" | substr(ICD,1,3) == "311"
    replace disease = "neurol_elixhauser" if substr(ICD,1,4) == "3319" | substr(ICD,1,4) == "3320" | ///
    substr(ICD,1,4) == "3334" | substr(ICD,1,4) == "3335" | substr(ICD,1,4) == "3481" | ///
    substr(ICD,1,4) == "3483" | substr(ICD,1,4) == "7803" | substr(ICD,1,4) == "7843" | ///
    substr(ICD,1,3) == "340"
    replace disease = "neurol_elixhauser" if ICD >= "3340" & substr(ICD,1,4) <= "3359"
    replace disease = "neurol_elixhauser" if ICD >= "3411" & substr(ICD,1,4) <= "3419"
    replace disease = "neurol_elixhauser" if ICD >= "34500" & ICD <= "34511"
    replace disease = "neurol_elixhauser" if ICD >= "34540" & ICD <= "34551"
    replace disease = "neurol_elixhauser" if ICD >= "34580" & ICD <= "34591"
    replace disease = "ischemic_stroke" if ICD == "43301" | ICD == "43311" | ICD == "43321" | ///
    ICD == "43331" | ICD == "43381" | ICD == "43391"
    replace disease = "ischemic_stroke" if ICD >= "43400" & ICD <= "43491"
end

*EXECUTE
main 08 07
