version 12
set more off
set type double
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    load_xwalk
    make_phys_visits
    count_visits
end

program load_xwalk

    import excel using "../external/xwalk/Primary Care v Specialist Crosswalks.xlsx", ///
      cellrange(A3:D120) firstrow clear
    drop if _n < 4
    rename HCFASpecialtyCode hcfaspcl
    rename PrimaryCare primary
    rename Specialist specialist
    destring primary, replace
    destring specialist, replace

    keep primary specialist hcfaspcl
    save ../temp/hcfa_primary_or_specialist_xwalk, replace

end

program make_phys_visits
    foreach y in 07 08 {
        use bene_id hcfaspcl expnsdt1 ///
          using ../external_links/car`y'/carl20`y'.dta, clear
        merge m:1 hcfaspcl using ../temp/hcfa_primary_or_specialist_xwalk, ///
          assert(1 2 3) keep(1 3) keepusing(primary specialist)

        collapse (max) primary specialist, by(bene_id expnsdt1)
        save ../temp/phys_visits_`y'.dta, replace
    }
end

program count_visits

    use ../temp/phys_visits_07, clear
    append using ../temp/phys_visits_08
    save ../temp/phys_visits_07_08, replace

    use ../external_links/event/event2008, clear
    merge 1:m bene_id using ../temp/phys_visits_07_08.dta, ///
      assert(1 2 3) keep(1 3) keepusing(primary specialist expnsdt1) nogen
    replace primary = 0 if primary == .
    replace specialist = 0 if specialist == .
    rename expnsdt1 date
    drop if t0 <= date | t0 - date > 365
    gen m03 = cond(date < t0 & date >= t0 - 90, 1, 0)
    gen m36 = cond(date < t0 - 90 & date >= t0 - 180, 1, 0)
    gen m69 = cond(date < t0 - 180 & date >= t0 - 270, 1, 0)
    gen m912 = cond(date < t0 - 270 & date >= t0 - 365, 1, 0)
    gen m01 = cond(date < t0 & date >= t0 - 30, 1, 0)
    gen m112 = cond(date < t0 - 30 & date >= t0 - 365, 1, 0)
    gen d01 = cond(date < t0 - 0 & date >= t0 - 1, 1, 0)
    gen d03 = cond(date < t0 - 0 & date >= t0 - 3, 1, 0)
    gen d07 = cond(date < t0 - 0 & date >= t0 - 7, 1, 0)

    foreach date_range in m03 m36 m69 m912 m01 m112 d01 d03 d07 {
        gen primary_`date_range' = primary * `date_range'
        gen specialist_`date_range' = specialist * `date_range'
    }

    collapse (sum) primary* specialist*, by(bene_id)
    save_data ../output/physician_visits_y08, key(bene_id) replace

end

* EXECUTE
main
