version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries

program main
    foreach year in 2007 2008 {
        inpatient, year(`year')
        outpatient, year(`year')
        carrier, year(`year')
    }
    append_data
end

program inpatient
    syntax, year(string)
    use bene_id t0 using ../external_links/event/event2008.dta, clear
    merge 1:m bene_id using ../external/inpatient/ip20_clms_raw_`year', ///
      assert(1 2 3) keep(3) keepusing(*) nogen
    gen diff_date = t0 - from_dt
    keep if diff_date > 0 & diff_date <= 365
    drop diff_date t0
    save_data "../output/inpatient/ip20_clms_raw_`year'", key(bene_id CLM_ID) replace
end

program outpatient
    syntax, year(string)
    use bene_id t0 using ../external_links/event/event2008.dta, clear
    merge 1:m bene_id using ../external/outpatient/op20_clms_raw_`year', ///
      assert(1 2 3) keep(3) keepusing(*) nogen
    gen diff_date = t0 - from_dt
    keep if diff_date > 0 & diff_date <= 365
    drop diff_date t0
    save_data "../output/outpatient/op20_clms_raw_`year'", key(bene_id CLM_ID) replace
end

program carrier
    syntax, year(string)
    use bene_id t0 using ../external_links/event/event2008.dta, clear
    merge 1:m bene_id using ../external/carrier/car20_clmline_raw_`year', ///
      assert(1 2 3) keep(3) keepusing(*) nogen
    gen diff_date = t0 - from_dt
    keep if diff_date > 0 & diff_date <= 365
    drop diff_date t0
    save "../output/carrier/car20_clmline_raw_`year'", replace
end

program append_data
    use ../output/inpatient/ip20_clms_raw_2007, clear
    append using ../output/inpatient/ip20_clms_raw_2008
    save ../output/inpatient/ip20_clms_raw_2007_2008, replace

    use ../output/outpatient/op20_clms_raw_2007, clear
    append using ../output/outpatient/op20_clms_raw_2008
    save ../output/outpatient/op20_clms_raw_2007_2008, replace

    use ../output/carrier/car20_clmline_raw_2007, clear
    append using ../output/carrier/car20_clmline_raw_2008
    save ../output/carrier/car20_clmline_raw_2007_2008, replace
end

* EXECUTE
main
