version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries

*2008 real
global ipc_08 "../external_links/ip08/ipc2008.dta"
global opc_08 "../external_links/op08/opc2008.dta"
global opr_08 "../external_links/op08/opr2008.dta"
global carc_08 "../external_links/car08/carc2008.dta"
global carl_08 "../external_links/car08/carl2008.dta"

*2009 real
global ipc_09 "../external_links/ip09/ipc2009.dta"
global opc_09 "../external_links/op09/opc2009.dta"
global opr_09 "../external_links/op09/opr2009.dta"
global carc_09 "../external_links/car09/carc2009.dta"
global carl_09 "../external_links/car09/carl2009.dta"

program main
    foreach data in "real" {
        foreach type in "ip" "op" "car"{
            foreach year in 08 09 {
                narrow_`type'_claims `year' `data'
            }
            combine `type' `data'
        }

        calc_horizon "ip" `data' "admsn_dt"
        calc_horizon "op" `data' "rev_dt"
        calc_horizon "car" `data' "expnsdt1"

        foreach h in 7 30 90 365 {
            initialize_globals
            ip_pmt `h' `data'
            op_pmt `h' `data'
            tot_pmt `h' `data'
            spending_categories `h' `data'
        }
    }
end

    program narrow_ip_claims
        args year data
        use ${ipc_`year'}, clear

        merge m:1 bene_id using ../external_links/event/event2008, ///
            assert(master using match) keep(match) keepusing(bene_id t0) nogen
        replace pmt_amt = 0 if pmt_amt < 0
        replace pmt_amt = pmt_amt + per_diem * util_day
        drop if dschrgdt==.
        collapse (sum) pmt_amt (first) t0, by(bene_id admsn_dt dschrgdt)
        gen ip_pmt_amt_check = pmt_amt
        save ../temp/ip_dates_`year'_`data', replace
    end

    program narrow_op_claims
        args year data
        use ${opr_`year'}, clear
        collapse (min) rev_dt, by(bene_id clm_id) 

        merge 1:1 bene_id clm_id using ${opc_`year'}, ///
            assert(match) keep(match) nogen
        merge m:1 bene_id using ../external_links/event/event2008, ///
            assert(master using match) keep(match) keepusing(bene_id t0) nogen
        replace pmt_amt = 0 if pmt_amt < 0
        collapse (sum) pmt_amt (first) t0, by(bene_id rev_dt)
        save ../temp/op_dates_`year'_`data', replace
    end

    program narrow_car_claims
        args year data
        use ${carl_`year'}, clear
        collapse (min) expnsdt1, by(bene_id clm_id) 

        merge 1:1 bene_id clm_id using ${carc_`year'}, ///
            assert(match) keep(match) nogen
        merge m:1 bene_id using ../external_links/event/event2008, ///
            assert(master using match) keep(match) keepusing(bene_id t0) nogen
        replace pmt_amt = 0 if pmt_amt < 0
        collapse (sum) pmt_amt (first) t0, by(bene_id expnsdt1)
        save ../temp/car_dates_`year'_`data', replace
    end

    program combine
        args type data
        use ../temp/`type'_dates_08_`data', clear
        append using ../temp/`type'_dates_09_`data'
        save ../temp/`type'_dates_`data', replace
    end

    program calc_horizon
        args type data date
        use ../temp/`type'_dates_`data'.dta, clear
        scalar date_all = _N
        gen date_diff = `date' - t0
        drop if date_diff < 0
        drop if date_diff > 365

        foreach h in 7 30 90 365 {
            preserve
            keep if date_diff <= `h'
            save ../temp/`type'_dates`h'_`data', replace
            if "`type'" != "ip" {
                save ../temp/`type'_dates_orig`h'_`data', replace
            }
            restore
        }
    end

    program initialize_globals
        global checksums "ip_pmt_amt_check"
        foreach x of global checksums {
            global tot_`x' = 0
        }
    end

    program ip_pmt
        args h data
        use ../temp/ip_dates`h'_`data'.dta, clear
        make_checksums, checksums(`"ip_pmt_amt_check"')
        bys bene_id: gen visit = _n
        su visit
        save ../temp/ip_events`h'_`data', replace
        global N = r(max)
        //In each iteration of the loops, taking out OP and CAR claims in IP and not replacing!!
        forvalues v=1/${N} {
            use bene_id admsn_dt dschrgdt visit using ../temp/ip_events`h'_`data', clear
            keep if visit == `v'
            merge 1:m bene_id using ../temp/op_dates`h'_`data'.dta, assert(master using match) /// 
                 keep(using match) keepusing(pmt_amt rev_dt) nogen
            preserve
            keep if inrange(rev_dt, admsn_dt, dschrgdt) & admsn_dt != .
            save ../temp/ip_op_visit`h'_`v'_`data', replace
            restore
            drop if inrange(rev_dt, admsn_dt, dschrgdt) & admsn_dt != .
            save ../temp/op_dates`h'_`data', replace
         }

        forvalues v = 1/${N} {
            use bene_id admsn_dt dschrgdt visit using ../temp/ip_events`h'_`data', clear
            keep if visit == `v'
            merge 1:m bene_id using ../temp/car_dates`h'_`data',  assert(master using match) /// 
                 keep(using match) keepusing(pmt_amt expnsdt1) nogen
            preserve 
            keep if inrange(expnsdt1, admsn_dt, dschrgdt) & admsn_dt != .
            save ../temp/ip_car_visit`h'_`v'_`data', replace
            restore
            drop if inrange(expnsdt1, admsn_dt, dschrgdt) & admsn_dt != .
            save ../temp/car_dates`h'_`data', replace
        }

        use ../temp/ip_events`h'_`data', clear
        forvalues v = 1/${N} {
            append using "../temp/ip_op_visit`h'_`v'_`data'"
            append using "../temp/ip_car_visit`h'_`v'_`data'"
        }
        collapse (sum) pmt_amt ip_pmt_amt_check, by(bene_id)
        run_data_checks
        drop ip_pmt_amt_check
        ren pmt_amt ip_pmt_amt

        label var ip_pmt_amt "IP pmt in `y' for horizon `h'"

        save "../temp/ip_pmt`h'_`data'", replace
    end

        program make_checksums
            syntax, checksums(string)
            foreach x of local checksums {
                summarize `x', meanonly
                global tot_`x' = ${tot_`x'}+r(sum)
            }
        end

        program run_data_checks
            foreach x of global checksums {
                summarize `x', meanonly
                local temp = r(sum)
                capture assert ${tot_`x'} == `temp'
                di("Global: ${tot_`x'}")
                di("After collapse: `temp'")
                if (_rc != 0) display "ERROR: NOT CONSERVING `x'"
            }
        end

    program op_pmt
        args h data
        use ../temp/op_dates`h'_`data'.dta, clear
        append using ../temp/car_dates`h'_`data'.dta
        collapse (sum) pmt_amt, by(bene_id)
        ren pmt_amt op_pmt_amt
        label var op_pmt_amt "OP pmt in `y' for horizon `h'"
        save "../temp/op_pmt`h'_`data'", replace
    end

    program tot_pmt
        args h data
        use ../temp/ip_dates`h'_`data'.dta, clear
        append using ../temp/op_dates_orig`h'_`data'
        append using ../temp/car_dates_orig`h'_`data'
        collapse (sum) pmt_amt, by(bene_id)
        ren pmt_amt tot_pmt_amt
        label var tot_pmt_amt "Total pmt in `y' for horizon `h'"
        save "../temp/tot_pmt`h'_`data'", replace
    end

    program spending_categories
        args h data
        use bene_id t0 using ../external_links/event/event2008, clear
        merge 1:m bene_id using ../temp/ip_pmt`h'_`data'.dta, ///
            assert(master match) keep(master match) nogen
        merge 1:m bene_id using ../temp/op_pmt`h'_`data'.dta, ///
            assert(master match) keep(master match) nogen
        merge 1:m bene_id using ../temp/tot_pmt`h'_`data'.dta, ///
            assert(master match) keep(master match) nogen

        foreach x of varlist *_pmt_amt {
            replace `x' = 0 if mi(`x')
        }

        gen check_pmt_amt = 1
        gen temp_pmt_amt = ip_pmt_amt + op_pmt_amt
        gen diff_pmt_amt = tot_pmt_amt - temp_pmt_amt
        replace check_pmt_amt = 0 if abs(diff_pmt_amt) < 0.1
        tab check_pmt_amt

        keep bene_id tot_* ip_* op_*
        save_data ../output/spending_event_`h'_`data'.dta, key(bene_id) replace ///
            log(../output/data_file_manifest.log)
        describe using ../output/spending_event_`h'_`data'.dta
    end

*EXECUTE
main

