version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries

program main 
    args y l
/*
    my_sample `y' 100
    ip_last `y' `l'
    op_last `y' `l'
    car_last `y' `l'
    tot_pmt `y'
    ip_pmt `y'
    op_pmt `y'
    combine_pmt `y'
    ip_visits_procedures `y' `l'
*/
    op_er_visits `y' `l'
end 

program my_sample
    args y pc
    if `pc' == 1 {
        use bene_id t0 using "../external_links/event/event2008", clear
        set seed 1
        gen u = runiform()
        keep if u < .01
    }
    else if `pc' == 100 {
        use bene_id t0 using "../external_links/event/event2008", clear
    }
    save ../temp/sample, replace
end

program ip_last
    args y l
    use ../external/ip_visits/ip_visits_20`l', clear
    append using ../external/ip_visits/ip_visits_2008
    save ../temp/ip_visits_`l'_`y', replace
    use bene_id t0 using ../temp/sample, clear
    merge 1:m bene_id using ../temp/ip_visits_`l'_`y', ///
        assert(1 2 3) keep(3) nogen
    // in 1 if no ip event in either year and in 2 if not a decedent within horizon
    gen diff_date = t0 - admsn_dt
    keep if diff_date > 0 & diff_date <= 365
    bys bene_id: gen visit = _n
    save ../temp/ip_dates_`y', replace
    gen bene_pay = ded_amt + coin_amt //these are never missing
    foreach v of varlist pmt_amt bene_pay prpayamt {
        gen `v'_m13 = `v' * cond(admsn_dt < t0 & admsn_dt >= t0 - 90, 1, 0)
        gen `v'_m36 = `v' * cond(admsn_dt < t0 - 90 & admsn_dt >= t0 - 180, 1, 0)
        gen `v'_m69 = `v' * cond(admsn_dt < t0 - 180 & admsn_dt >= t0 - 270, 1, 0)
        gen `v'_m912 = `v' * cond(admsn_dt < t0 - 270 & admsn_dt >= t0 - 365, 1, 0)
        gen `v'_m01 = `v' * cond(admsn_dt < t0 - 0 & admsn_dt >= t0 - 30, 1, 0)
        gen `v'_m112 = `v' * cond(admsn_dt < t0 - 30 & admsn_dt >= t0 - 365, 1, 0)
        gen `v'_d01 = `v' * cond(admsn_dt < t0 - 0 & admsn_dt >= t0 - 1, 1, 0)
        gen `v'_d03 = `v' * cond(admsn_dt < t0 - 0 & admsn_dt >= t0 - 3, 1, 0)
        gen `v'_d07 = `v' * cond(admsn_dt < t0 - 0 & admsn_dt >= t0 - 7, 1, 0)
    }
    collapse (sum) pmt_amt* bene_pay* prpayamt* (first) t0, by(bene_id)
    save ../temp/ip_file_pmt_`y', replace
end

program op_last
    args y l
    use ../external_links/op`l'/opr20`l', clear
    append using ../external_links/op`y'/opr20`y'
    save ../temp/opr_`l'_`y', replace
    use ../external_links/op`l'/opc20`l', clear
    append using ../external_links/op`y'/opc20`y'
    save ../temp/opc_`l'_`y', replace
    use bene_id t0 using ../temp/sample, clear
    merge 1:m bene_id using ../temp/opr_`l'_`y', ///
        assert(1 2 3) keep(3) keepusing(clm_id rev_dt)
    // in 2 if not a decedent within horizon and in 1 if no op claims in the last year
    drop if rev_dt == .
    // we can't assign spending to any horizon if the rev_dt is missing
    collapse (min) rev_dt (first) t0, by(bene_id clm_id)
    merge 1:1 bene_id clm_id using ../temp/opc_`l'_`y', ///
        assert(2 3) keep(3) keepusing(pmt_amt ptb_ded ptb_coin blddedam prpayamt) nogen 
    gen diff_date = t0 - rev_dt
    keep if diff_date > 0 & diff_date <= 365

    foreach var in pmt_amt ptb_ded ptb_coin blddedam prpayamt {
        assert !mi(`var')
    }

    gen bene_pay = ptb_ded + ptb_coin + blddedam
    foreach v of varlist pmt_amt bene_pay prpayamt {
        gen `v'_m13 = `v' * cond(rev_dt < t0 & rev_dt >= t0 - 90, 1, 0)
        gen `v'_m36 = `v' * cond(rev_dt < t0 - 90 & rev_dt >= t0 - 180, 1, 0)
        gen `v'_m69 = `v' * cond(rev_dt < t0 - 180 & rev_dt >= t0 - 270, 1, 0)
        gen `v'_m912 = `v' * cond(rev_dt < t0 - 270 & rev_dt >= t0 - 365, 1, 0)
        gen `v'_m01 = `v' * cond(rev_dt < t0 - 0 & rev_dt >= t0 - 30, 1, 0)
        gen `v'_m112 = `v' * cond(rev_dt < t0 - 30 & rev_dt >= t0 - 365, 1, 0)
        gen `v'_d01 = `v' * cond(rev_dt < t0 - 0 & rev_dt >= t0 - 1, 1, 0)
        gen `v'_d03 = `v' * cond(rev_dt < t0 - 0 & rev_dt >= t0 - 3, 1, 0)
        gen `v'_d07 = `v' * cond(rev_dt < t0 - 0 & rev_dt >= t0 - 7, 1, 0)
    }
    save ../temp/op_dates, replace
    save ../temp/op_dates_orig_`y', replace
end

program car_last
    args y l
    use ../external_links/car`l'/carl20`l', clear
    append using ../external_links/car`y'/carl20`y'
    save ../temp/carl_`l'_`y', replace
    use ../external_links/car`l'/carc20`l', clear
    append using ../external_links/car`y'/carc20`y'
    save ../temp/carc_`l'_`y', replace
    use bene_id t0 using ../temp/sample, clear
    merge 1:m bene_id using ../temp/carl_`l'_`y', ///
        assert(1 2 3) keep(3) keepusing(clm_id expnsdt1 coinamt ldedamt) nogen
    // in 2 if not a decedent within horizon and in 1 if no car claims in the last year
    drop if expnsdt1 == .
    // we can't assign spending to any horizon if the expnsdt1 is missing
    collapse (min) expnsdt1 (sum) coinamt ldedamt (first) t0, by(bene_id clm_id)
    merge 1:1 bene_id clm_id using ../temp/carc_`l'_`y', ///
        assert(2 3) keep(3) keepusing(pmt_amt prpayamt) nogen
    gen diff_date = t0 - expnsdt1 
    keep if diff_date > 0 & diff_date <= 365

    foreach var in pmt_amt prpayamt {
        assert !mi(`var')
    }

    gen bene_pay = coinamt + ldedamt
    foreach v of varlist pmt_amt bene_pay prpayamt {
        gen `v'_m13 = `v' * cond(expnsdt1 < t0 & expnsdt1 >= t0 - 90, 1, 0)
        gen `v'_m36 = `v' * cond(expnsdt1 < t0 - 90 & expnsdt1 >= t0 - 180, 1, 0)
        gen `v'_m69 = `v' * cond(expnsdt1 < t0 - 180 & expnsdt1 >= t0 - 270, 1, 0)
        gen `v'_m912 = `v' * cond(expnsdt1 < t0 - 270 & expnsdt1 >= t0 - 365, 1, 0)
        gen `v'_m01 = `v' * cond(expnsdt1 < t0 - 0 & expnsdt1 >= t0 - 30, 1, 0)
        gen `v'_m112 = `v' * cond(expnsdt1 < t0 - 30 & expnsdt1 >= t0 - 365, 1, 0)
        gen `v'_d01 = `v' * cond(expnsdt1 < t0 - 0 & expnsdt1 >= t0 - 1, 1, 0)
        gen `v'_d03 = `v' * cond(expnsdt1 < t0 - 0 & expnsdt1 >= t0 - 3, 1, 0)
        gen `v'_d07 = `v' * cond(expnsdt1 < t0 - 0 & expnsdt1 >= t0 - 7, 1, 0)
    }
    save ../temp/car_dates, replace
    save ../temp/car_dates_orig_`y', replace
end

program tot_pmt
    args y
    use ../temp/ip_file_pmt_`y', clear
    append using ../temp/op_dates_orig_`y'
    append using ../temp/car_dates_orig_`y'
    collapse (sum) pmt_amt* bene_pay* prpayamt*, by(bene_id)
    foreach var of varlist pmt_amt* bene_pay* prpayamt* {
        ren `var' tot_`var'
    }
    label var tot_pmt_amt "Total pmt in `y' for horizon"
    label var tot_bene_pay "Total OOP pay in `y' for horizon"
    label var tot_prpayamt "Total non-Medicare primary payer pay in `y' for horizon"
    save ../temp/tot_pmt_y`y', replace
end

program ip_pmt
    args y
    use ../temp/ip_dates_`y', clear
    su visit
    global N = r(max)
    forvalues v = 1/${N} {
        use bene_id admsn_dt dschrgdt visit using ../temp/ip_dates_`y', clear
        keep if visit == `v'
        merge 1:m bene_id using ../temp/op_dates, /// 
            assert(1 2 3) keep(2 3) keepusing(pmt_amt* bene_pay* prpayamt* rev_dt) nogen
        preserve 
        keep if inrange(rev_dt, admsn_dt, dschrgdt) & admsn_dt != .
        save ../temp/ip_op_visit`v'_`y', replace
        restore
        drop if inrange(rev_dt, admsn_dt, dschrgdt) & admsn_dt != .
        save ../temp/op_dates, replace
    }
    forvalues v = 1/${N} {
        use bene_id admsn_dt dschrgdt visit using ../temp/ip_dates_`y', clear
        keep if visit == `v'
        merge 1:m bene_id using ../temp/car_dates, /// 
            assert(1 2 3) keep(2 3) keepusing(pmt_amt* bene_pay* prpayamt* expnsdt1) nogen
        preserve 
        keep if inrange(expnsdt1, admsn_dt, dschrgdt) & admsn_dt != .
        save ../temp/ip_car_visit`v'_`y', replace
        restore
        drop if inrange(expnsdt1, admsn_dt, dschrgdt) & admsn_dt != .
        save ../temp/car_dates, replace
    }
    use ../temp/ip_file_pmt_`y', clear
    forvalues v = 1/${N} {
        append using "../temp/ip_op_visit`v'_`y'"
        append using "../temp/ip_car_visit`v'_`y'"
    }
    collapse (sum) pmt_amt* bene_pay* prpayamt*, by(bene_id)
    foreach var of varlist pmt_amt* bene_pay* prpayamt* {
        ren `var' ip_`var'
    }
    label var ip_pmt_amt "IP pmt in `y' for horizon"
    label var ip_bene_pay "IP OOP pay in `y' for horizon"
    label var ip_prpayamt "IP non-Medicare primary payer pay in `y' for horizon"
    save "../temp/ip_pmt_y`y'", replace
end

program op_pmt
    args y
    use ../temp/op_dates, clear
    append using ../temp/car_dates
    collapse (sum) pmt_amt* bene_pay* prpayamt*, by(bene_id)
    foreach var of varlist pmt_amt* bene_pay* prpayamt* {
        ren `var' op_`var'
    }
    label var op_pmt_amt "OP pmt in `y' for horizon"
    label var op_bene_pay "OP OOP pay in `y' for horizon"
    label var op_prpayamt "OP non-Medicare primary payer pay in `y' for horizon"
    save "../temp/op_pmt_y`y'", replace
end

program combine_pmt
    args y
    use bene_id using "../temp/sample", clear
    merge 1:1 bene_id using "../temp/tot_pmt_y`y'", nogen
    merge 1:1 bene_id using "../temp/ip_pmt_y`y'", nogen
    merge 1:1 bene_id using "../temp/op_pmt_y`y'", nogen
    foreach v of varlist tot_* ip_* op_* {
        replace `v' = 0 if `v' == .
    }
    keep bene_id tot_* ip_* op_*
    save_data "../output/prior_pmt_y`y'", key(bene_id) replace
end

program ip_visits_procedures
    args y l
    use bene_id t0 using "../temp/sample", clear
    merge 1:m bene_id using "../temp/ip_visits_`l'_`y'", ///
        assert(1 2 3) keep(1 3) keepusing(admsn_dt er num_prcdrs num_visits num_ip_days) nogen
    * in 1 if no ip claim in last year and in 2 if not in sample, e.g., in hmo
    ren er num_ip_er_visits
    ren num_visits num_ip_visits
    foreach v of varlist num_ip_er_visits num_prcdrs num_ip_visits num_ip_days {
        gen `v'_m13 = `v' * cond(admsn_dt < t0 & admsn_dt >= t0 - 90, 1, 0)
        gen `v'_m36 = `v' * cond(admsn_dt < t0 - 90 & admsn_dt >= t0 - 180, 1, 0)
        gen `v'_m69 = `v' * cond(admsn_dt < t0 - 180 & admsn_dt >= t0 - 270, 1, 0)
        gen `v'_m912 = `v' * cond(admsn_dt < t0 - 270 & admsn_dt >= t0 - 365, 1, 0)
        gen `v'_m01 = `v' * cond(admsn_dt < t0 - 0 & admsn_dt >= t0 - 30, 1, 0)
        gen `v'_m112 = `v' * cond(admsn_dt < t0 - 30 & admsn_dt >= t0 - 365, 1, 0)
        gen `v'_d01 = `v' * cond(admsn_dt < t0 - 0 & admsn_dt >= t0 - 1, 1, 0)
        gen `v'_d03 = `v' * cond(admsn_dt < t0 - 0 & admsn_dt >= t0 - 3, 1, 0)
        gen `v'_d07 = `v' * cond(admsn_dt < t0 - 0 & admsn_dt >= t0 - 7, 1, 0)
    }
    collapse (sum) *_m13 *_m36 *_m69 *_m912 *_m01 *_m112 *_d01 *_d03 *_d07, by(bene_id)
    save_data "../output/prior_ip_y`y'", key(bene_id) replace
end

program op_er_visits
    args y l
    use bene_id t0 using "../temp/sample", clear
    merge 1:m bene_id using "../temp/opr_`l'_`y'", ///
        assert(1 2 3) keep(1 3) keepusing(rev_cntr rev_dt) nogen
    * in 1 if no op claim in last year and in 2 if not in sample, e.g., in hmo
    * www.resdac.org/resconnect/articles/144
    gen er = rev_cntr == "0981"
    forvalues c = 450/459 {
        local code = "0" + "`c'"
        replace er = 1 if rev_cntr == "`code'"
    }
    collapse (max) er t0, by(bene_id rev_dt)
    gen num_op_er_visits_m13 = er * cond(rev_dt < t0 - 0 & rev_dt >= t0 - 90, 1, 0)
    gen num_op_er_visits_m36 = er * cond(rev_dt < t0 - 90 & rev_dt >= t0 - 180, 1, 0)
    gen num_op_er_visits_m69 = er * cond(rev_dt < t0 - 180 & rev_dt >= t0 - 270, 1, 0)
    gen num_op_er_visits_m912 = er * cond(rev_dt < t0 - 270 & rev_dt >= t0 - 365, 1, 0)
    gen num_op_er_visits_m01 = er * cond(rev_dt < t0 - 0 & rev_dt >= t0 - 30, 1, 0)
    gen num_op_er_visits_m112 = er * cond(rev_dt < t0 - 30 & rev_dt >= t0 - 365, 1, 0)
    gen num_op_er_visits_d01 = er * cond(rev_dt < t0 - 0 & rev_dt >= t0 - 1, 1, 0)
    gen num_op_er_visits_d03 = er * cond(rev_dt < t0 - 0 & rev_dt >= t0 - 3, 1, 0)
    gen num_op_er_visits_d07 = er * cond(rev_dt < t0 - 0 & rev_dt >= t0 - 7, 1, 0)
    collapse (sum) num*, by(bene_id)
    save_data "../output/prior_op_y`y'", key(bene_id) replace
end

*EXECUTE
main 08 07
