version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

global ipc_07 "../external/ip_cleaned/ip_visits_2007.dta"
global ipc_08 "../external/ip_cleaned/ip_visits_2008.dta"
global ipc_09 "../external/ip_cleaned/ip_visits_2009.dta"

program main
    foreach year in "07" "08" "09" {
        prepare_ip `year'
        prepare_op `year'
    }
    calc_horizon 07 08
    calc_horizon 08 09
    op_er_visits 07 08
    op_er_visits 08 09
end

program prepare_ip
    args year
    use ${ipc_`year'}, clear
    merge m:1 bene_id using ../external_links/event/event2008.dta, ///
      assert(master using match) keep(match) keepusing(bene_id t0) nogen
    save ../temp/ip_event_`year'.dta, replace
end

program prepare_op
    args year
    use ../external_links/op`year'/opr20`year', clear
    merge m:1 bene_id using ../external_links/event/event2008.dta, ///
      assert(1 2 3) keep(3) keepusing(bene_id t0) nogen
    save ../temp/op_event_`year'.dta, replace
end

program calc_horizon
    args y1 y2
    use ../temp/ip_event_`y1'.dta, clear
    append using ../temp/ip_event_`y2'
    gen date_diff = admsn_dt - t0
    drop if date_diff < 0 | date_diff > 365
    foreach h in 7 365 {
        preserve
        keep if date_diff <= `h'

        collapse (sum) num_visits num_ip_days num_prcdrs num_icu_visits num_ip_er_visits, by(bene_id)

        merge m:1 bene_id using ../external_links/event/event2008.dta, ///
          assert(using match) keep(using match) keepusing(bene_id) nogen
        foreach var of varlist num_* {
            replace `var' = 0 if mi(`var')
        }
        save_data ../output/ip_visits_days_prcdrs`h'_`y1'.dta, key(bene_id) replace ///
          log(../output/data_file_manifest.log)
        restore
    }
end

program op_er_visits
    args y1 y2
    use ../temp/op_event_`y1'.dta, clear
    append using ../temp/op_event_`y2'
    gen er = rev_cntr=="0981"
    forvalue c=450/459 {
        local code = "0" + "`c'"
        replace er = 1 if rev_cntr=="`code'"
    }
    gen date_diff = rev_dt - t0
    drop if date_diff < 0 | date_diff > 365
    collapse (max) er (firstnm) t0 rev_dt, by(bene_id clm_id)
    gen date_diff = rev_dt - t0
    foreach h in 7 365 {
        preserve
        keep if date_diff <= `h'

        collapse (sum) num_op_er_visits=er, by(bene_id)

        merge m:1 bene_id using ../external_links/event/event2008.dta, ///
          assert(using match) keep(using match) keepusing(bene_id) nogen
        foreach var of varlist num_op_er_visits {
            replace `var' = 0 if mi(`var')
        }
        save_data ../output/op_er_visits`h'_`y1'.dta, key(bene_id) replace ///
          log(../output/data_file_manifest.log)
        restore
    }
end

* EXECUTE
main
