version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries

*2007 real
global ipc_07 "../external/ip_visits/ip_visits_2007.dta"
global opc_07 "../external_links/op07/opc2007.dta"
global opr_07 "../external_links/op07/opr2007.dta"
global carc_07 "../external_links/car07/carc2007.dta"
global carl_07 "../external_links/car07/carl2007.dta"

*2008 real
global ipc_08 "../external/ip_visits/ip_visits_2008.dta"
global opc_08 "../external_links/op08/opc2008.dta"
global opr_08 "../external_links/op08/opr2008.dta"
global carc_08 "../external_links/car08/carc2008.dta"
global carl_08 "../external_links/car08/carl2008.dta"

*2010 real
global ipc_10 "../external/ip_visits/ip_visits_2010.dta"
global opc_10 "../external_links/op10/opc2010.dta"
global opr_10 "../external_links/op10/opr2010.dta"
global carc_10 "../external_links/car10/carc2010.dta"
global carl_10 "../external_links/car10/carl2010.dta"

*2011 real
global ipc_11 "../external/ip_visits/ip_visits_2011.dta"
global opc_11 "../external_links/op11/opc2011.dta"
global opr_11 "../external_links/op11/opr2011.dta"
global carc_11 "../external_links/car11/carc2011.dta"
global carl_11 "../external_links/car11/carl2011.dta"

program main 
    args h y l
    decedents `h' `y'
    ip_last `h' `y' `l'
    op_last `h' `y' `l'
    car_last `h' `y' `l'
    tot_pmt `h' `y'
    ip_pmt `h' `y'
    op_pmt `h' `y'
    combine_pmt `h' `y'
end 

program decedents
    args h y
    use bene_id sdod using "../external_links/jan/1jan`y'", clear
    gen days_survived = sdod - date("1JAN`y'", "DMY") 
    gen days_backfill = `h' - days_survived
    gen mort = days_survived < `h'
    keep if mort == 1
    save ../temp/mort_h`h'_y`y', replace
end

program ip_last
    args h y l
    use bene_id days_backfill using "../temp/mort_h`h'_y`y'", clear
    merge 1:m bene_id using ${ipc_`l'}, ///
        assert(1 2 3) keep(3) nogen
    // in 1 if no ip event in last year and in 2 if not a decedent within horizon
    keep if admsn_dt >= date("1JAN`y'", "DMY") - days_backfill
    bys bene_id: gen visit = _n
    save ../temp/ip_dates_`h'_`y', replace
    gen bene_pay = ded_amt + coin_amt //these are never missing
    collapse (sum) pmt_amt bene_pay prpayamt, by(bene_id)
    save ../temp/ip_file_pmt_`h'_`y', replace
end

program op_last
    args h y l
    use bene_id days_backfill using "../temp/mort_h`h'_y`y'", clear
    merge 1:m bene_id using ${opr_`l'}, ///
        assert(1 2 3) keep(3) keepusing(clm_id rev_dt)
    // in 2 if not a decedent within horizon and in 1 if no op claims in the last year
    drop if rev_dt == .
    // we can't assign spending to any horizon if the rev_dt is missing
    keep if rev_dt >= date("1JAN`y'", "DMY") - days_backfill
    collapse (min) rev_dt, by(bene_id clm_id)
    merge 1:1 bene_id clm_id using ${opc_`l'}, ///
        assert(2 3) keep(3) keepusing(pmt_amt ptb_ded ptb_coin blddedam prpayamt) nogen 

    foreach var in pmt_amt ptb_ded ptb_coin blddedam prpayamt {
        assert !mi(`var')
    }
    replace pmt_amt = 0 if pmt_amt < 0
    gen bene_pay = ptb_ded + ptb_coin + blddedam
    save ../temp/op_dates, replace
    save ../temp/op_dates_orig_`h'_`y', replace
end

program car_last
    args h y l
    use bene_id days_backfill using "../temp/mort_h`h'_y`y'", clear
    merge 1:m bene_id using ${carl_`l'}, ///
        assert(1 2 3) keep(3) keepusing(clm_id expnsdt1 coinamt ldedamt) nogen
    // in 2 if not a decedent within horizon and in 1 if no car claims in the last year
    drop if expnsdt1 == .
    // we can't assign spending to any horizon if the expnsdt1 is missing
    keep if expnsdt1 >= date("1JAN`y'", "DMY") - days_backfill
    collapse (min) expnsdt1 (sum) coinamt ldedamt, by(bene_id clm_id)
    merge 1:1 bene_id clm_id using ${carc_`l'}, ///
        assert(2 3) keep(3) keepusing(pmt_amt prpayamt) nogen

    foreach var in pmt_amt prpayamt {
        assert !mi(`var')
    }
    replace pmt_amt = 0 if pmt_amt < 0
    gen bene_pay = coinamt + ldedamt
    save ../temp/car_dates, replace
    save ../temp/car_dates_orig_`h'_`y', replace
end

program tot_pmt
    args h y
    use ../temp/ip_file_pmt_`h'_`y', clear
    append using ../temp/op_dates_orig_`h'_`y'
    append using ../temp/car_dates_orig_`h'_`y'
    collapse (sum) pmt_amt bene_pay prpayamt, by(bene_id)
    foreach var of varlist pmt_amt bene_pay prpayamt {
        ren `var' tot_`var'
    }
    label var tot_pmt_amt "Total pmt in `y' for horizon `h'"
    label var tot_bene_pay "Total OOP pay in `y' for horizon `h'"
    label var tot_prpayamt "Total non-Medicare primary payer pay in `y' for horizon `h'"
    save ../temp/tot_pmt_h`h'_y`y', replace
end

program ip_pmt
    args h y
    use ../temp/ip_dates_`h'_`y', clear
    su visit
    global N = r(max)
    forvalues v = 1/${N} {
        use bene_id admsn_dt dschrgdt visit using ../temp/ip_dates_`h'_`y', clear
        keep if visit == `v'
        merge 1:m bene_id using ../temp/op_dates, /// 
            assert(1 2 3) keep(2 3) keepusing(pmt_amt bene_pay prpayamt rev_dt) nogen
        preserve 
        keep if inrange(rev_dt, admsn_dt, dschrgdt) & admsn_dt != .
        save ../temp/ip_op_visit`v'_`h'_`y', replace
        restore
        drop if inrange(rev_dt, admsn_dt, dschrgdt) & admsn_dt != .
        save ../temp/op_dates, replace
    }
    forvalues v = 1/${N} {
        use bene_id admsn_dt dschrgdt visit using ../temp/ip_dates_`h'_`y', clear
        keep if visit == `v'
        merge 1:m bene_id using ../temp/car_dates, /// 
            assert(1 2 3) keep(2 3) keepusing(pmt_amt bene_pay prpayamt expnsdt1) nogen
        preserve 
        keep if inrange(expnsdt1, admsn_dt, dschrgdt) & admsn_dt != .
        save ../temp/ip_car_visit`v'_`h'_`y', replace
        restore
        drop if inrange(expnsdt1, admsn_dt, dschrgdt) & admsn_dt != .
        save ../temp/car_dates, replace
    }
    use ../temp/ip_file_pmt_`h'_`y', clear
    forvalues v = 1/${N} {
        append using "../temp/ip_op_visit`v'_`h'_`y'"
        append using "../temp/ip_car_visit`v'_`h'_`y'"
    }
    collapse (sum) pmt_amt bene_pay prpayamt, by(bene_id)
    foreach var of varlist pmt_amt bene_pay prpayamt {
        ren `var' ip_`var'
    }
    label var ip_pmt_amt "IP pmt in `y' for horizon `h'"
    label var ip_bene_pay "IP OOP pay in `y' for horizon `h'"
    label var ip_prpayamt "IP non-Medicare primary payer pay in `y' for horizon `h'"
    save "../temp/ip_pmt_h`h'_y`y'", replace
end

program op_pmt
    args h y
    use ../temp/op_dates, clear
    append using ../temp/car_dates
    collapse (sum) pmt_amt bene_pay prpayamt, by(bene_id)
    foreach var of varlist pmt_amt bene_pay prpayamt {
        ren `var' op_`var'
    }
    label var op_pmt_amt "OP pmt in `y' for horizon `h'"
    label var op_bene_pay "OP OOP pay in `y' for horizon `h'"
    label var op_prpayamt "OP non-Medicare primary payer pay in `y' for horizon `h'"
    save "../temp/op_pmt_h`h'_y`y'", replace
end

program combine_pmt
    args h y
    use "../temp/mort_h`h'_y`y'", clear
    merge 1:1 bene_id using "../temp/tot_pmt_h`h'_y`y'", nogen
    merge 1:1 bene_id using "../temp/ip_pmt_h`h'_y`y'", nogen
    merge 1:1 bene_id using "../temp/op_pmt_h`h'_y`y'", nogen
    foreach v of varlist tot_* ip_* op_* {
        replace `v' = 0 if `v' == .
    }

    foreach v in "pmt_amt" "bene_pay" "prpayamt" {
        gen check_`v' = 1
        gen temp_`v' = ip_`v' + op_`v'
        gen diff_`v' = tot_`v' - temp_`v'
        replace check_`v' = 0 if abs(diff_`v') < 0.1
        tab check_`v'
        drop temp_`v' diff_`v' check_`v'
    }
    keep bene_id tot_* ip_* op_*
    save_data "../output/backfill_pmt_h`h'_y`y'", key(bene_id) replace
end

*EXECUTE
foreach horizon in 7 30 90 365 {
    main `horizon' 2008 07
}
