version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

global ipc_07 "../external/ip_cleaned/ip_visits_2007.dta"
global ipc_08 "../external/ip_cleaned/ip_visits_2008.dta"

program main
    foreach year in "07" "08" {
        prepare_ip `year' 08
    }
    calc_horizon 08
end

program prepare_ip
    args year sample_year
    use ${ipc_`year'}, clear
    merge m:1 bene_id using ../external_links/jan/1jan20`sample_year'.dta, ///
      assert(master using match) keep(match) keepusing(sdod) nogen
    save ../temp/ip_jan1_`year'.dta, replace
end

program calc_horizon
    args year
    foreach h in 7 365 {
        use ../temp/ip_jan1_07.dta, clear
        gen jan1_date = date("January 1, 20`year'", "MDY")
        format jan1_date %td

        gen days_survived = sdod - jan1_date
        gen days_backfill = `h' - days_survived
        keep if admsn_dt >= jan1_date - days_backfill

        save ../output/backfill_ip_visits`h'_08.dta, replace
        collapse (sum) num_visits num_ip_days num_prcdrs num_icu_visits num_ip_er_visits, by(bene_id)

        merge m:1 bene_id using ../external_links/jan/1jan20`year'.dta, ///
          assert(using match) keep(using match) keepusing(bene_id) nogen
        foreach var of varlist num_* {
            replace `var' = 0 if mi(`var')
        }
        save_data ../output/backfill_ip_visits_days_prcdrs`h'_`year'.dta, key(bene_id) replace ///
          log(../output/data_file_manifest.log)
    }
end

* EXECUTE
main
