version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    foreach y in "08" {
        foreach h in 7 30 90 365 {
            prep_back `h' `y'
            merge_w_backfill `h' `y'
        }
    }
end

program prep_back
    args h y
    /*Forward-spending contains all beneficiaries, regardless of whether or not
    they had spending. There are no missing outcome variable values*/
    /*Backfill spending only contains people who died*/
    use ../external/backfill/backfill_pmt_h`h'_y20`y'.dta, clear
    foreach var in "tot" "ip" "op" {
        foreach pmt in "pmt_amt" "bene_pay" "prpayamt" {
            rename `var'_`pmt' back_`var'_`pmt' 
        }
    }
    save ../temp/backfill_h`h'_y20`y'.dta, replace
end

program merge_w_backfill
    args h y
    use ../external/spending/spending_jan1_`h'_`y'_real.dta, clear
    foreach var of varlist ip_* op_* tot_* {
        assert !mi(`var')
    }
    merge 1:1 bene_id using ../temp/backfill_h`h'_y20`y'.dta, ///
        assert(master match) keep(master match) nogen
    foreach var of varlist back_* {
        replace `var' = 0 if mi(`var')
    }
    foreach var in "tot" "ip" "op" {
        foreach pmt in "pmt_amt" "bene_pay" "prpayamt" {
            gen `var'_`pmt'_backfilled = `var'_`pmt' + back_`var'_`pmt'
        }
    }
    save_data ../output/spending_backfilled_h`h'_jan`y'.dta, key(bene_id) replace ///
        log(../output/data_file_manifest.log)
end

* EXECUTE
main
    
