version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

*2008 real
global ipc_08 "../external/ip_cleaned/ip_visits_2008.dta"
global opc_08 "../external_links/op08/opc2008.dta"
global opr_08 "../external_links/op08/opr2008.dta"
global carc_08 "../external_links/car08/carc2008.dta"
global carl_08 "../external_links/car08/carl2008.dta"

*2011 real
global ipc_11 "../external/ip_cleaned/ip_visits_2011.dta"
global opc_11 "../external_links/op11/opc2011.dta"
global opr_11 "../external_links/op11/opr2011.dta"
global carc_11 "../external_links/car11/carc2011.dta"
global carl_11 "../external_links/car11/carl2011.dta"

program main
    foreach data in "real" {
        foreach year in "08" "11" {
            foreach type in "ip" "op" "car"{
                narrow_`type'_claims `year' `data'
            }
            neg_table `year' `data'

            calc_horizon "ip" `year' `data' "admsn_dt"
            calc_horizon "op" `year' `data' "rev_dt"
            calc_horizon "car" `year' `data' "expnsdt1"
            date_check `year' `data'

            foreach h in 7 30 60 90 180 365 {
                initialize_globals
                ip_pmt `h' `year' `data'
                op_pmt `h' `year' `data'
                tot_pmt `h' `year' `data'
                spending_categories `h' `year' `data'
            }
        }
    }
end

    program narrow_ip_claims
        args year data
        use ${ipc_`year'}, clear //already on bene_id-admsn_dt-dschrgdt level

        merge m:1 bene_id using ../external_links/jan/1jan20`year'.dta, ///
            assert(master using match) keep(match) keepusing(bene_id) nogen

        scalar initial_ip_obs = _N
        gen bene_pay = ded_amt + coin_amt + blddedam
        gen ip_pmt_amt_check = pmt_amt

        keep bene_id admsn_dt dschrgdt pmt_amt bene_pay prpayamt ip_pmt_amt_check
        save ../temp/ip_dates_`year'_`data'.dta, replace
    end

    program narrow_op_claims
        args year data
        use ${opr_`year'}, clear
        collapse (min) rev_dt, by(bene_id clm_id) 

        merge 1:1 bene_id clm_id using ${opc_`year'}, ///
            assert(match) keep(match) nogen
        merge m:1 bene_id using ../external_links/jan/1jan20`year'.dta, ///
            assert(master using match) keep(match) keepusing(bene_id) nogen

        gen bene_pay = ptb_ded + ptb_coin + blddedam
        neg_checks
        collapse (sum) pmt_amt bene_pay prpayamt, by(bene_id rev_dt)

        save ../temp/op_dates_`year'_`data', replace
    end

        program neg_checks
            scalar tot_clms = _N
            gen neg_pmt = pmt_amt < 0

            count if neg_pmt == 1
            scalar all_neg = r(N)

            gen neg_from_deductible = (bene_pay > 0) & (neg_pmt == 1)
            count if neg_from_deductible == 1
            scalar neg_explained = r(N)

            gen final_check = bene_pay + pmt_amt
            gen problem = (final_check <= 0) & (neg_pmt == 1)

            count if problem == 1
            scalar problem = r(N)
            replace pmt_amt = 0 if pmt_amt < 0
            drop neg_pmt neg_from_deductible final_check problem

            mat neg_claims = (tot_clms \ all_neg \ neg_explained \ problem)
            mat neg_mat = nullmat(neg_mat), neg_claims
        end

    program narrow_car_claims
        args year data
        use ${carl_`year'}, clear
        collapse (min) expnsdt1 (sum) coinamt ldedamt, by(bene_id clm_id) 

        merge 1:1 bene_id clm_id using ${carc_`year'}, ///
            assert(match) keep(match) nogen
        merge m:1 bene_id using ../external_links/jan/1jan20`year'.dta, ///
            assert(master using match) keep(match) keepusing(bene_id) nogen

        gen bene_pay = ldedamt + coinamt 
        neg_checks
        collapse (sum) pmt_amt bene_pay prpayamt, by(bene_id expnsdt1)

        save ../temp/car_dates_`year'_`data', replace
    end

    program neg_table
        args year data
        matrix colnames neg_mat = "op" "car"
        matrix rownames neg_mat = "Tot claims `year'" "All neg claims" ///
            "Explained neg" "Non-explained neg"
        matrix list neg_mat
        matrix_to_txt, matrix(neg_mat) saving(../output/tables_counts.txt) ///
            title(<tab:neg_`year'_`data'>) append
    end

    program initialize_globals
        global checksums "ip_pmt_amt_check"
        foreach x of global checksums {
            global tot_`x' = 0
        }
    end

    program calc_horizon
        args type year data date
        use ../temp/`type'_dates_`year'_`data'.dta, clear
        scalar date_all = _N
        gen jan1_date = date("January 1, 20`year'", "MDY")
        format jan1_date %td
        gen date_diff = `date' - jan1_date

        count if date_diff < 0
        scalar date_0 = r(N)
        drop if date_diff < 0
        count if date_diff > 365
        scalar date_365 = r(N)
        drop if date_diff > 365
        scalar date_final = _N

        matrix date_mat = (date_all \ date_0 \ date_365 \ date_final)
        matrix h_date_mat = nullmat(h_date_mat), date_mat

        foreach h in 7 30 60 90 180 365 {
            preserve
            keep if date_diff <= `h'
            save ../temp/`type'_dates`h'_`year'_`data', replace
            if "`type'" != "ip" {
                save ../temp/`type'_dates_orig`h'_`year'_`data', replace
            }
            restore
        }
    end

    program date_check
        args year data
        matrix colnames h_date_mat = "ip" "op" "car"
        matrix rownames h_date_mat = "Initial" "date_diff<0" "date_diff>365" "Final"
        matrix list h_date_mat
        matrix_to_txt, matrix(h_date_mat) saving(../output/tables_counts.txt) ///
            title(<tab:h_date_`year'_`data'>) append
    end

    program ip_pmt
        args h year data
        use ../temp/ip_dates`h'_`year'_`data'.dta, clear
        make_checksums, checksums(`"ip_pmt_amt_check"')
        bys bene_id: gen visit = _n
        su visit
        save ../temp/ip_events`h'_`year'_`data'.dta, replace
        global N = r(max)
        //In each iteration of the loops, taking out OP and CAR claims in IP and not replacing!!
        forvalues v=1/${N} {
            use bene_id admsn_dt dschrgdt visit using ../temp/ip_events`h'_`year'_`data', clear
            keep if visit == `v'
            merge 1:m bene_id using ../temp/op_dates`h'_`year'_`data'.dta, assert(master using match) /// 
                 keep(using match) keepusing(pmt_amt bene_pay prpayamt rev_dt) nogen
            preserve
            keep if inrange(rev_dt, admsn_dt, dschrgdt) & admsn_dt != .
            save ../temp/ip_op_visit`h'_`v'_`year'_`data', replace
            restore
            drop if inrange(rev_dt, admsn_dt, dschrgdt) & admsn_dt != .
            save ../temp/op_dates`h'_`year'_`data', replace
         }

        forvalues v = 1/${N} {
            use bene_id admsn_dt dschrgdt visit using ../temp/ip_events`h'_`year'_`data', clear
            keep if visit == `v'
            merge 1:m bene_id using ../temp/car_dates`h'_`year'_`data',  assert(master using match) /// 
                 keep(using match) keepusing(pmt_amt bene_pay prpayamt expnsdt1) nogen
            preserve 
            keep if inrange(expnsdt1, admsn_dt, dschrgdt) & admsn_dt != .
            save ../temp/ip_car_visit`h'_`v'_`year'_`data', replace
            restore
            drop if inrange(expnsdt1, admsn_dt, dschrgdt) & admsn_dt != .
            save ../temp/car_dates`h'_`year'_`data', replace
        }

        use ../temp/ip_events`h'_`year'_`data', clear
        forvalues v = 1/${N} {
            append using "../temp/ip_op_visit`h'_`v'_`year'_`data'"
            append using "../temp/ip_car_visit`h'_`v'_`year'_`data'"
        }
        collapse (sum) pmt_amt bene_pay prpayamt ip_pmt_amt_check, by(bene_id)
        run_data_checks
        drop ip_pmt_amt_check
        foreach var of varlist pmt_amt bene_pay prpayamt {
            ren `var' ip_`var'
        }
        label var ip_pmt_amt "IP pmt in `y' for horizon `h'"
        label var ip_bene_pay "IP OOP pay in `y' for horizon `h'"
        label var ip_prpayamt "IP non-Medicare primary payer pay in `y' for horizon `h'"
        save "../temp/ip_pmt`h'_`year'_`data'", replace
    end

        program make_checksums
            syntax, checksums(string)
            foreach x of local checksums {
                summarize `x', meanonly
                global tot_`x' = ${tot_`x'}+r(sum)
            }
        end

        program run_data_checks
            foreach x of global checksums {
                summarize `x', meanonly
                local temp = r(sum)
                capture assert ${tot_`x'} == `temp'
                di("Global: ${tot_`x'}")
                di("After collapse: `temp'")
                if (_rc != 0) display "ERROR: NOT CONSERVING `x'"
            }
        end

    program op_pmt
        args h year data
        use ../temp/op_dates`h'_`year'_`data'.dta, clear
        append using ../temp/car_dates`h'_`year'_`data'.dta
        collapse (sum) pmt_amt bene_pay prpayamt, by(bene_id)
        foreach var of varlist pmt_amt bene_pay prpayamt {
            ren `var' op_`var'
        }
        label var op_pmt_amt "OP pmt in `y' for horizon `h'"
        label var op_bene_pay "OP OOP pay in `y' for horizon `h'"
        label var op_prpayamt "OP non-Medicare primary payer pay in `y' for horizon `h'"
        save "../temp/op_pmt`h'_`year'_`data'", replace
    end

    program tot_pmt
        args h year data
        use ../temp/ip_dates`h'_`year'_`data'.dta, clear
        append using ../temp/op_dates_orig`h'_`year'_`data'
        append using ../temp/car_dates_orig`h'_`year'_`data'
        collapse (sum) pmt_amt bene_pay prpayamt, by(bene_id)
        foreach var of varlist pmt_amt bene_pay prpayamt {
            ren `var' tot_`var'
        }
        label var tot_pmt_amt "Total pmt in `y' for horizon `h'"
        label var tot_bene_pay "Total OOP pay in `y' for horizon `h'"
        label var tot_prpayamt "Total non-Medicare primary payer pay in `y' for horizon `h'"
        save "../temp/tot_pmt`h'_`year'_`data'", replace
    end

    program spending_categories
        args h year data
        use bene_id using ../external_links/jan/1jan20`year'.dta, clear
        merge 1:m bene_id using ../temp/ip_pmt`h'_`year'_`data'.dta, ///
            assert(master match) keep(master match) nogen
        merge 1:m bene_id using ../temp/op_pmt`h'_`year'_`data'.dta, ///
            assert(master match) keep(master match) nogen
        merge 1:m bene_id using ../temp/tot_pmt`h'_`year'_`data'.dta, ///
            assert(master match) keep(master match) nogen

        foreach x of varlist tot_* ip_* op_* {
            replace `x' = 0 if mi(`x')
        }

        foreach v in "pmt_amt" "bene_pay" "prpayamt" {
            gen check_`v' = 1
            gen temp_`v' = ip_`v' + op_`v'
            gen diff_`v' = tot_`v' - temp_`v'
            replace check_`v' = 0 if abs(diff_`v') < 0.1
            tab check_`v'
            drop temp_`v' diff_`v' check_`v'
        }

        keep bene_id tot_* ip_* op_*
        save_data ../output/spending_jan1_`h'_`year'_`data'.dta, key(bene_id) replace ///
            log(../output/data_file_manifest.log)
        describe using ../output/spending_jan1_`h'_`year'_`data'.dta
    end

* EXECUTE
main
