version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

global ipc_07 "../external/ip_cleaned/ip_visits_2007.dta"
global ipc_08 "../external/ip_cleaned/ip_visits_2008.dta"

program main
        foreach year in "07" "08" {
            prepare_ip `year' 08
            calc_horizon `year' 08
            op_er_visits `year' 08
        }
end

program prepare_ip
    args year sample_year
    use ${ipc_`year'}, clear
    merge m:1 bene_id using ../external_links/jan/1jan20`sample_year'.dta, ///
      assert(master using match) keep(match) keepusing(bene_id) nogen
    save ../temp/ip_jan1_`year'.dta, replace
end

program calc_horizon
    args year sample_year
    use ../temp/ip_jan1_`year'.dta, clear
    gen jan1_date = date("January 1, 20`year'", "MDY")
    format jan1_date %td
    gen date_diff = admsn_dt - jan1_date
    drop if date_diff < 0 | date_diff > 365
    foreach h in 7 365 {
        preserve
        keep if date_diff <= `h'

        collapse (sum) num_visits num_ip_days num_prcdrs num_icu_visits num_ip_er_visits, ///
          by(bene_id)

        merge m:1 bene_id using ../external_links/jan/1jan20`sample_year'.dta, ///
          assert(using match) keep(using match) keepusing(bene_id) nogen
        foreach var of varlist num_* {
            replace `var' = 0 if mi(`var')
        }
        save_data ../output/ip_visits_days_prcdrs`h'_`year'.dta, key(bene_id) replace ///
          log(../output/data_file_manifest.log)
        describe using ../output/ip_visits_days_prcdrs`h'_`year'.dta
        restore
    }
end

program op_er_visits
    args year sample_year
    use ../external_links/jan/1jan20`sample_year', clear
    merge 1:m bene_id using ../external_links/op`year'/opr20`year', ///
      assert(1 2 3) keep(1 3) keepusing(rev_cntr rev_dt clm_id) nogen
    gen er = rev_cntr=="0981"
    forvalues c=450/459 {
        local code = "0" + "`c'"
        replace er = 1 if rev_cntr == "`code'"
    }
    collapse (max) er (firstnm) rev_dt, by(bene_id clm_id)
    gen jan1_date = date("January 1, 20`year'", "MDY")
    format jan1_date %td
    gen date_diff = rev_dt - jan1_date
    drop if date_diff < 0
    drop if date_diff > 365
    foreach h in 7 365 {
        preserve
        keep if date_diff <= `h'

        collapse (sum) num_op_er_visits=er, by(bene_id)

        merge m:1 bene_id using ../external_links/jan/1jan20`sample_year'.dta, ///
          assert(using match) keep(using match) keepusing(bene_id) nogen
        foreach var of varlist num_op_er_visits {
            replace `var' = 0 if mi(`var')
        }
        save_data ../output/op_er_visits`h'_`year'.dta, key(bene_id) replace ///
          log(../output/data_file_manifest.log)
        describe using ../output/op_er_visits`h'_`year'.dta
        restore
    }
end

* EXECUTE
main
