version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries

program main 
    args y l
    dgns_var `y'
    sample `y'
    ip_last `l'
    op_last `l'
    car_last `l'
    append_claims `y' `l'
    prepare_zocats
    merge_zocats `y'
    zocat_counts `y'
end 

program dgns_var
    args y
    if "`y'" == "08" {
        global dgns dgnscd1
        global cdgns dgns_cd1
    }
    else if "`y'" == "11" {
        global dgns icd_dgns_cd1
        global cdgns icd_dgns_cd1
    }
    else {
        di "`y' should be 08 or 11"
    }
end

program sample
    args y
    use bene_id using "../external_links/jan/1jan20`y'", clear
    save ../temp/sample, replace
end

program ip_last
    args l
    use ../temp/sample, clear
    merge 1:m bene_id using "../external/ip_visits/ip_visits_20`l'", ///
        assert(1 2 3) keep(3) keepusing(admsn_dt dgnscd1) nogen
    // in 1 if no ip event in last year 
    // in 2 if not in sample 
    if "`y'" == "11" {
        ren dgnscd1 icd_dgns_cd1
    }
    duplicates drop
    save ../temp/ip_dgns`l', replace
end

program op_last
    args l
    use ../temp/sample, clear
    merge 1:m bene_id using "../external_links/op`l'/opr20`l'", ///
        assert(1 2 3) keep(3) keepusing(clm_id rev_dt)
    // in 1 if no op claims in the last year
    // in 2 if not a decedent within horizon 
    collapse (min) rev_dt, by(bene_id clm_id)
    merge 1:1 bene_id clm_id using "../external_links/op`l'/opc20`l'", ///
        assert(2 3) keep(3) keepusing(${dgns}) nogen 
    save ../temp/op_dgns`l', replace
end

program car_last
    args l
    use ../temp/sample, clear
    merge 1:m bene_id using "../external_links/car`l'/carl20`l'", ///
        assert(1 2 3) keep(3) keepusing(clm_id expnsdt1) nogen
    // in 1 if no car claims in the last year
    // in 2 if not a decedent within horizon
    collapse (min) expnsdt1, by(bene_id clm_id)
    merge 1:1 bene_id clm_id using "../external_links/car`l'/carc20`l'", ///
        assert(2 3) keep(3) keepusing(${cdgns}) nogen
    if "${cdgns}" == "dgns_cd1" {
        ren dgns_cd1 dgnscd1
    }
    save ../temp/car_dgns`l', replace
end

program append_claims
     args y l
     use ../temp/ip_dgns`l'
     append using ../temp/op_dgns`l'
     append using ../temp/car_dgns`l'
     foreach v of varlist admsn_dt rev_dt expnsdt1 {
        replace `v' = 0 if `v'==.
     }
     gen date = admsn_dt + rev_dt + expnsdt1
     format %td date
     drop admsn_dt rev_dt expnsdt1
     save ../temp/appended`y', replace
end

program prepare_zocats
    import excel using ../external/zo/zo_cats_14_12_19.xlsx, first clear
    replace dgnscd = "none" if dgnscd==""
    replace zc = "dgnscd is missing" if dgnscd=="none"
    encode zc, gen(zcn)
    compress
    save ../temp/zo, replace
end

program merge_zocats
    args y
    use ../temp/appended`y', clear
    ren ${dgns} dgnscd
    merge m:1 dgnscd using ../temp/zo, ///
        assert(1 2 3) keep(1 3) keepusing(zcn) nogen
    // in 1 if dgnscd isn't in xwalk (if dgnscd is empty)
    // in 2 if dgnscd isn't in claims data (could be many)
    drop if missing(zcn)
    drop if zcn=="dgnscd is missing":zcn
    bysort bene_id zcn date: gen dup=cond(_N==1, 0, _n) 
    drop if dup > 1
    drop dup 
    save ../temp/zocats, replace
end

program zocat_counts
    args y
    use ../temp/sample, clear
    gen t0 = date("1JAN20`y'", "DMY")
    merge 1:m bene_id using ../temp/zocats, assert(1 2 3) keep(3) nogen
    drop if t0 <= date | t0 - date > 365
    gen m03_zc = cond(date < t0 & date >= t0 - 90, 1, 0)
    gen m36_zc = cond(date < t0 - 90 & date >= t0 - 180, 1, 0)
    gen m69_zc = cond(date < t0 - 180 & date >= t0 - 270, 1, 0)
    gen m912_zc = cond(date < t0 - 270 & date >= t0 - 365, 1, 0)
    gen m01_zc = cond(date < t0 & date >= t0 - 30, 1, 0)
    gen m112_zc = cond(date < t0 - 30 & date >= t0 - 365, 1, 0)
    gen d01_zc = cond(date < t0 - 0 & date >= t0 - 1, 1, 0)
    gen d03_zc = cond(date < t0 - 0 & date >= t0 - 3, 1, 0)
    gen d07_zc = cond(date < t0 - 0 & date >= t0 - 7, 1, 0)
    collapse (sum) m03_zc m36_zc m69_zc m912_zc m01_zc m112_zc d01_zc d03_zc d07_zc, ///
      by(bene_id zcn t0)
    egen zcg = group(zcn)
    save_data ../output/zocat_reshape_ready_`y', replace key(bene_id zcn)
    su zcg
    global G = r(max)
    preserve
    keep zcn zcg
    duplicates drop
    decode zcn, gen(zc)
    save_data ../output/zc_dict, key(zc) replace
    restore
    foreach h in m03 m36 m69 m912 m01 m112 d01 d03 d07 { 
        forvalues i = 0/60 {
            use ../output/zocat_reshape_ready_`y', clear
	    keep bene_id `h'_zc zcg
	    local n = `i'*50 + 1
	    local m = (`i' + 1) * 50
	    keep if inrange(zcg, `n', `m')
            count
            if `r(N)' > 0 {
	        reshape wide `h'_zc, i(bene_id) j(zcg)
                save ../temp/zc_`h'_`i', replace
            }
        }
        use ../temp/zc_`h'_0, clear
	forvalues i = 1/60 {
	    capture merge 1:1 bene_id using ../temp/zc_`h'_`i', ///
                assert(1 2 3) keep(1 2 3) nogen
	}
        foreach v of varlist `h'* {
            replace `v' = 0 if `v' == .
        }
	save_data ../output/zc_`h'_y`y', key(bene_id) replace
    }
end

*EXECUTE
main 08 07
