version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    build_data
    backfill_a
    backfill_b
    backfill_c
    merge_data
end

program build_data
    use ../external_links/jan/1jan2008.dta, clear
    gen days_surv = sdod - date("1JAN2008", "DMY")
    gen days_backfill = 365 - days_surv
    replace days_backfill = 0 if days_backfill < 0
    gen month_of_death = month(sdod) if mort365
    gen yod = year(sdod) if mort365
    gen n = 1
    merge 1:1 bene_id using ../external/spending/prior_pmt_y08, ///
      assert(3) keep(3) keepusing(tot_pmt_amt) nogen
    save ../temp/sample, replace
end

program backfill_a
    use ../temp/sample, clear
    keep if month_of_death != .
    collapse (mean) tot_pmt_amt, by(month_of_death)
    gen daily_pmt_amt = tot_pmt_amt / 365
    save ../temp/backfilled_by_month, replace
    use bene_id month_of_death days_backfill mort365 using ../temp/sample, clear
    merge m:1 month_of_death using ../temp/backfilled_by_month, ///
      assert(1 2 3) keep(1 2 3) keepusing(daily_pmt_amt) nogen
    gen backfill_a = days_backfill * daily_pmt_amt
    replace backfill_a = 0 if !mort365
    save ../temp/backfilled_a, replace
end

program backfill_b
    use ../temp/sample, clear
    keep if mort365
    collapse (mean) tot_pmt_amt, by(mort365)
    gen daily_pmt_amt = tot_pmt_amt / 365
    save ../temp/backfilled_by_mort, replace
    use bene_id month_of_death days_backfill mort365 using ../temp/sample, clear
    merge m:1 mort365 using ../temp/backfilled_by_mort, ///
      assert(1 2 3) keep(1 2 3) keepusing(daily_pmt_amt) nogen
    gen backfill_b = days_backfill * daily_pmt_amt
    replace backfill_b = 0 if !mort365
    save ../temp/backfilled_b, replace
end

program backfill_c
    use ../temp/sample, clear
    collapse (mean) tot_pmt_amt, by(n)
    gen daily_pmt_amt = tot_pmt_amt / 365
    save ../temp/backfilled_by_all, replace
    use bene_id month_of_death days_backfill n mort365 using ../temp/sample, clear
    merge m:1 n using ../temp/backfilled_by_all, ///
      assert(1 2 3) keep(1 2 3) keepusing(daily_pmt_amt) nogen
    gen backfill_c = days_backfill * daily_pmt_amt
    replace backfill_c = 0 if !mort365
    save ../temp/backfilled_c, replace
end

program merge_data
    use ../temp/backfilled_a, clear
    foreach l in b c {
        merge 1:1 bene_id using ../temp/backfilled_`l', ///
          assert(3) keep(3) keepusing(backfill_`l') nogen
    
    }
    save ../temp/other_backfill, replace
    use bene_id tot_pmt_amt using ../external/spending_08/spending_jan1_365_08_real.dta, clear
    merge 1:1 bene_id using ../temp/other_backfill, ///
      assert(1 3) keep(3) keepusing(backfill_*) nogen
    foreach l in a b c {
        gen tot_pmt_backfilled_`l' = tot_pmt_amt + backfill_`l'
    }
    save ../output/other_backfill, replace
end

* EXECUTE
main
