# Reqiured Packages
require(tidyr)
require(dplyr)
require(ggplot2)
require(ggthemes)
require(foreign)
require(data.table)  
require(reshape2)
library(RColorBrewer)


# Turns NAs into 0s
f_dowle3 = function(DT) {
    for (j in seq_len(ncol(DT)))
        set(DT,which(is.na(DT[[j]])),j,0)
}

# Createas performance indicators: AUC, ppv80, sens95, and spec95

perfIndicators=function(yhat,y){
  output<-data.frame(variable=deparse(substitute(y)),AUC=0,sens95=0,spec95=0,ppv80=0)
  output[1,]$AUC<-AUC::auc(roc(yhat,as.factor(y)))
  pred <- ROCR::prediction(yhat, y)
  perf <- ROCR::performance(pred, 'sens','spec')
  output[1,]$spec95<-perf@x.values[[1]][which.min(abs(perf@y.values[[1]]-.95))]
  output[1,]$sens95<-perf@y.values[[1]][which.min(abs(perf@x.values[[1]]-.95))]
  perf <- ROCR::performance(pred, 'sens','ppv')
  output[1,]$ppv80<-perf@x.values[[1]][which.min(abs(perf@y.values[[1]]-.8))]
  return(output)
}

# Counts number of zeros in a column
iszero=function(x){return(length(which((x!=0))))}


# Read diagnosis codes in -- level is bene-index date- diagnosis code-time period-count
allzc=read.dta('allzc_to_R.dta')
setDT(allzc)
# allzc[,index_dt:=as.character(index_dt)]
keycols = c("bene_id","index_dt")
setkeyv(allzc,keycols)
allzc[,d_1324:=NULL]
#RESHAPE WIDE level is bene - index date
wide=dcast.data.table(allzc,bene_id + index_dt~zc,value.var=c("d_01","d_112"))

# Do the same for Chemo codes
chemozc=read.dta('chemo_to_r.dta')
setDT(chemozc)
setkeyv(chemozc,keycols)
chemozc[,d_1324:=NULL]
widechemo=dcast.data.table(chemozc,bene_id + index_dt~hcpcs_cd,value.var=c("d_01","d_112"))

f_dowle3(wide)
keycols = c("bene_id","index_dt")
setkeyv(wide,keycols)

#Merge the data together 

BINS=read.dta("BINSstarterkit.dta")
setDT(BINS)
BINS[,index_dt:=as.character(index_dt)]
keycols = c("bene_id","index_dt")
setkeyv(BINS,keycols)
wide[,index_dt:=as.character(index_dt)]
binsstep1=merge(BINS,wide,all.x=TRUE)


widechemo[,index_dt:=as.character(index_dt)]

Finalbins=merge(binsstep1,widechemo,all.x=TRUE)

f_dowle3(Finalbins)

save(Finalbins,file="Finalbins.Rdata")

## Remove all variables with more than 99.9% missingness

varclasses=sapply(Finalbins,iszero)
varclasses=varclasses[varclasses<314]
todrop=names(varclasses)
Smallbins=copy(Finalbins)
Smallbins[,(todrop):=NULL]
save(Smallbins,file="Smallbins.Rdata")

### BREAK HERE IF NEEDED ###


require(tidyr)
require(dplyr)
require(ggplot2)
require(ggthemes)
require(foreign)
require(data.table)  # v1.6.6
require(reshape2)
library(RColorBrewer)
library(xgboost)
library(caret)
load("Smallbins.Rdata")

# training and testing cohorts

train=Smallbins[group==0]
test=Smallbins[group==1]

# outcomes & training data

y = train$death

X = as.matrix(train[,c("bene_id", "index_dt", "survtime","death","death_dt","group","bene_zip"):=NULL])



# train models

dtrain <- xgb.DMatrix(data = X,label=y)

# hyperparameters may vary -- CV for best performance
bst <- xgboost(data = dtrain,"max.depth" = 9, eta = .01, nround = 500,bag.fraction = .9,eval_metric="auc",objective = "binary:logistic")


#CHECK VARIABLE IMPORTANCE
asdfbst <- xgboost(data = dtrain,"max.depth" = 1, eta = .01, nround = 1,bag.fraction = 1,eval_metric="auc",objective = "binary:logistic")

cathallimp=xgb.importance(bignames, model = asdfbst)

# save model
save(bst,file="bst.Rdata")

# predict output
X.test = as.matrix(test[,c("bene_id", "index_dt", "survtime","death","death_dt","group","bene_zip"):=NULL])
preds4=predict(bst,X.test)
# get model performance
perfIndicators(preds4,Smallbins[group==1]$death)
 
# auce plot
png('BIN_AUC.png')
plot.new()
plot(roc(preds4,as.factor(Smallbins[group==1]$death)))
title(main="Model AUC")

dev.off()

auc(roc(preds4,as.factor(Smallbins[group==1]$death)))


CancerCohortsOrigins.dta

test=Smallbins[group==1]
test$yhat=preds4

# FIGURE 1

plot1=test%>%mutate(percentile=ntile(yhat,100))%>%group_by(percentile)%>%summarise(death=mean(death),probrisk=mean(yhat)*100,n=n())%>%mutate(SE= sqrt(death*(1-death)/n))

fig1r=ggplot(data=plot1,aes(x=probrisk,y=(1-death)*100))+geom_line(alpha=.8,color="black",linetype="dotted")+geom_ribbon(aes(ymin=((1-death)-1.96*SE)*100, ymax=((1-death)+1.96*SE)*100), alpha=0.6)+
theme_bw() +
  theme(text=element_text(size=20),axis.line = element_line(colour = "black"),
        plot.title=element_text(lineheight=10,colour="black", family="sans"), plot.margin=unit(c(1,1,1,1), "cm"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),     

        legend.text=element_text(colour="black", family="sans", size=14), 
        legend.title=element_text(colour="black", family="sans", size=14),strip.background = element_rect(colour = "white", fill = "white"),strip.text=element_text(colour="black", family="sans", size=14))+
xlab("Predicted Probability of Death (yhat)")+ylab("Percent")+ggtitle("Survival Overall Cohort")
# ggsave(p34,file='Figure1r.png')
save(fig1r,file="fig1r.Rdata")


p34=ggplot(data=plot1,aes(x=percentile*5,y=(1-death)*100))+geom_line(alpha=.8,color="#6E3274")+geom_ribbon(aes(ymin=((1-death)-1.96*SE)*100, ymax=((1-death)+1.96*SE)*100), alpha=0.2)+
theme_bw() +
  theme(axis.line = element_line(colour = "black"),
        plot.title=element_text(lineheight=10,colour="black", family="sans"), plot.margin=unit(c(1,1,1,1), "cm"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),     

        legend.text=element_text(colour="black", family="sans", size=14), 
        legend.title=element_text(colour="black", family="sans", size=14),strip.background = element_rect(colour = "white", fill = "white"),strip.text=element_text(colour="black", family="sans", size=14))+
xlab("Predicted Probability of Death (percentile)")+ylab("Percent")+ggtitle("Survival Overall Cohort")
ggsave(p34,file='Figure1p.png')

ff=arrange_grob

cats=read.dta('CancerCohortsOrigins.dta')
setDT(cats)
cats[,index_dt:=as.character(index_dt)]
keycols = c("bene_id","index_dt")
setkeyv(cats,keycols)
cats[,index_dt:=NULL]
testcats=merge(test,cats,by="bene_id",all.x=TRUE)


plot1=testcats%>%mutate(percentile=ntile(yhat,25))%>%group_by(percentile,cancer)%>%summarise(death=mean(death),n=n())%>%mutate(SE= sqrt(death*(1-death)/n))

fig1c=ggplot(data=plot1,aes(x=percentile,y=(1-death)*100,color=cancer,fill=cancer))+geom_line(size=1.5,alpha=1,color='black',linetype='dotted')+geom_point(alpha=.1)+geom_ribbon(aes(ymin=((1-death)-1.96*SE)*100, ymax=((1-death)+1.96*SE)*100),color=NA, alpha=0.6)+
theme_bw() +facet_wrap(~cancer,ncol=2)+
  theme(text=element_text(size=20),axis.line = element_line(colour = "black"),
        plot.title=element_text(lineheight=10,colour="black", family="sans"), plot.margin=unit(c(1,1,1,1), "cm"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),legend.position="bottom",   
        legend.text=element_text(colour="black", family="sans", size=14), 
        legend.title=element_text(colour="black", family="sans", size=14),strip.background = element_rect(colour = "white", fill = "white"),strip.text=element_text(colour="black", family="sans", size=14))+
xlab("Predicted Probably of Death")+ylab("Percent")+ggtitle("Survival By Original Cancer Cohort")+scale_fill_brewer(palette="Set1",name="Primary cancer")+scale_color_brewer(palette="Set1",name="Primary cancer")
save(fig1c,file="fig1c.Rdata")
ggsave(p34,file='Figure1c.png',height=12,width=12)


load("~/Work/fig1c.Rdata")
load("~/Work/fig1r.Rdata")
grid.arrange(fig1r,fig1c,ncol=1,nrow=2,heights=c(1,3))


## HEAT MAP! ##

test[death==0,survtime:=366]
test[survtime>365,survtime:=366]
test[,survmonths:=ceiling(survtime/30)]
test[survmonths==13, survmonths:=12]
test[,yhatround:=cut(yhat,seq(0,1.1,.1))]
test[,yhatround2:=min(yhat),by=yhatround]
test[,yhatround:=yhatround2]
#test[yhatround==0,yhatround:=.1]
#test[,yhatround:=yhatround-.1]

# cut into bins


# create hm dt
library(dplyr)
library(zoo)

heatmap= test%>%group_by(yhatround,survmonths)%>%summarize(n=n())%>%arrange(survmonths)%>%mutate(died=cumsum(n))
heatmap[yhatround<.05,yhatround:=0]
heatmap[,yhatround:=round(yhatround,2)]

heatmap[,alive:=max(died),by="yhatround"]
heatmap[,propalive:=1-died/alive]
heatmap[survmonths==12,propalive:=n/died]

# # supply missing bins
# target <- expand.grid(yhatround = seq(0,.9,.1), survmonths = seq(0,12,1))
# heatmap <- merge(heatmap, target, by = c("yhatround", "survmonths"), all.y=T)
# heatmap <- heatmap %>% arrange(yhatround, survmonths)
# heatmap[, propalive := na.locf(propalive, fromlLast=F)]
#   # [ ] program generalization: logical check -- none should be NA: s[survmonths==0]

# heatmap=heatmap[survmonths<13]
# rounds=rep(0.0007296396,8)
# months=c(1,3,4,5,6,7,10,11)
# dat=data.table(yhatround=rounds,survmonths=months,propalive=.995)
# heatmap=rbindlist(list(heatmap,dat),fill=TRUE)
library(grid)
library(gridExtra)
theme_nothing <- function(base_size = 12, base_family = "Helvetica")
  {
  theme_bw(base_size = base_size, base_family = base_family) %+replace%
      theme(
            rect             = element_blank(),
            line             = element_blank(),
            text             = element_blank(),
            axis.ticks.margin = unit(0, "lines")
           )
  }


a=colorRampPalette(c("#B30000","#FFFFFF"))(11)
b=colorRampPalette(c("#FFFFFF","#000080"))(11)
cols=c(a,b)
cols=cols[-11]
# heatmap=rbindlist(list(heatmap, 
#   as.list(c(0.0007296396,3,1,1,1,.99)),
#   as.list(c(0.0007296396,1,1,1,1,.99)),
#   as.list(c(0.0007296396,4,1,1,1,.99)),
#   as.list(c(0.0007296396,5,1,1,1,.99)),
#   as.list(c(0.0007296396,6,1,1,1,.99)),
#   as.list(c(0.0007296396,7,1,1,1,.99)),
#   as.list(c(0.0007296396,11,1,1,1,.99)),
#   as.list(c(0.0007296396,10,1,1,1,.99))

#   ))

a=data.table(yhatround=rep(0.0,5),survmonths=c(2,3,6,8,10),propalive=rep(1,5))
heatmap=rbind(heatmap,a,fill=TRUE)
p1 <- ggplot(heatmap, aes(ymin=yhatround, ymax=yhatround+0.1, xmin=survmonths, xmax=survmonths+1)) + 
  geom_rect(aes(fill=propalive)) +  scale_fill_gradientn(
    colours = cols,
   values=seq(0,1,.05))+ 
  theme(legend.position="none")+ scale_x_continuous(breaks=seq(0.5,12.5),labels=c("<1","1","2","3","4","5","6","7","8","9","10","11","12+"),expand=c(0,0))+
    scale_y_continuous(breaks=seq(0,1,.1),expand=c(0,0),limits=c(-0.02,1.02))+
      theme_bw() +
  theme(axis.line = element_line(colour = "black"),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.border = element_blank(),
    panel.background = element_blank(),legend.position="none") +xlab("Survival (months)")+ylab("Probability of Death")

save(p1,file="p1.Rdata")

ggsave(p1,file="hetmap.png")


px <- ggplot(heatmap, aes(ymin=round(yhatround,2)-.01, ymax=round(heatmap$yhatround,2)+0.02, xmin=survmonths, xmax=survmonths+1)) + 
  geom_rect(aes(fill=propalive)) +  scale_fill_gradientn(colours = cols,values=seq(0,1,.05),name="Proportion Surviving") + theme(legend.position="bottom", legend.direction="horizontal")+theme_bw(base_size=18)


g_legend<-function(a.gplot){
    tmp <- ggplot_gtable(ggplot_build(a.gplot))
    leg <- which(sapply(tmp$grobs, function(x) x$name) == "guide-box")
    legend <- tmp$grobs[[leg]]
    legend
}

legend <- g_legend(px)
save(legend,file='legend.Rdata')

p2 <- ggplot(test,aes(x=survmonths,y=-..count..))+geom_histogram(binwidth=1)+theme_bw()+theme_nothing()+xlim(1,13)+ggtitle("Survival (months)")

p3 <- ggplot(test,aes(x=yhatround,y=-..count..))+geom_histogram(binwidth=.1)+theme_bw()+theme_nothing()+xlim(0,1)+coord_flip()+ggtitle("Probability of Death")
save(p1,file="p1.Rdata")
save(p2,file="p2.Rdata")
save(p3,file="p3.Rdata")
save(legend,file="p4.Rdata")

x1 <- ggplot_gtable(ggplot_build(p1))
x2 <- ggplot_gtable(ggplot_build(p2))
x3 <- ggplot_gtable(ggplot_build(p3))

    maxWidth <- unit.pmax(x1$widths[2:3], x2$widths[2:3])

    maxWidth <- unit.pmax(x1$widths[2:3], x2$widths[2:3])
    x1$widths[2:3] <- maxWidth
    x2$widths[2:3] <- maxWidth


 p = rectGrob(gp=gpar(fill=NA,alpha=0))



p5 <- ggplot(test,aes(x=survmonths))+geom_histogram(binwidth=1)+theme_bw()+xlim(1,13)+ggtitle("Survival (months)")+ theme(axis.line=element_blank(),axis.text.x=element_blank(),
          axis.text.y=element_blank(),axis.ticks=element_blank(),
          axis.title.x=element_blank(),
          axis.title.y=element_blank(),legend.position="none",
          panel.background=element_blank(),panel.border=element_blank(),panel.grid.major=element_blank(),
          panel.grid.minor=element_blank(),plot.background=element_blank())

save(p5,file="p5.Rdata")
p6 <- ggplot(test,aes(x=yhatround,y=..count..))+geom_histogram(binwidth=.1)+theme_bw()+xlim(0,1)+coord_flip()+ggtitle("Probability of Death")+ theme(axis.line=element_blank(),axis.text.x=element_blank(),
          axis.text.y=element_blank(),axis.ticks=element_blank(),
          axis.title.x=element_blank(),
          axis.title.y=element_blank(),legend.position="none",
          panel.background=element_blank(),panel.border=element_blank(),panel.grid.major=element_blank(),
          panel.grid.minor=element_blank(),plot.background=element_blank())

save(p6,file="p6.Rdata")

load("~/Work/p5.Rdata")
load("~/Work/p1.Rdata")
load("~/Work/p6.Rdata")
load("~/Work/legend.Rdata")
p5=p5+ggtitle("")
p6=p6+ggtitle("")
p1=p1+theme(text=element_text(size=20))
grid.arrange(p5,legend,p1,p6,ncol=2,nrow=2,heights=c(1,3),widths=c(3,1))

## HRR MAP

library(ROCR)

hrrs=read.dta("binallhrr.dta")
setDT(hrrs)
hrrs[,index_dt:=as.character(index_dt)]
testz=test[,c('bene_id','yhat','death','index_dt'),with=FALSE]
hrrs=merge(hrrs,testz,by=c("bene_id","index_dt"))
hrrs$death=as.factor(hrrs$death)
pred <- prediction(hrrs$yhat, hrrs$death)
perf <- performance(pred, 'sens','ppv')

ix <- which.min(abs(perf@alpha.values[[1]] - .8))
specificity <- perf@.values[[1]][ix]
sensitivity <- perf@x.values[[1]][ix]
which.min(abs(x - 14))

perf@x.values[[1]][which.min(abs(perf@y.values[[1]]-.8))]

q=by(hrrs, hrrs$hrrnum,
   function(x) performance(prediction(x$yhat,x$death) ,'sens','ppv'))

threshold=function(perf){return(perf@x.values[[1]][which.min(abs(perf@y.values[[1]]-.8))])}

result=sapply(q,threshold)

output=data.frame(hrr=names(result),ppv=result)
save(output,file="ppv.Rdata")
AUC::auc(roc(hrrs$yhat,as.factor(hrrs$death)))
AUCS=hrrs%>%group_by(hrrnum)%>%summarize(AUC=auc(roc(yhat,death)),n=n())

save(AUCS,file="AUC.Rdata")
save(output,file="PPV.Rdata")