/* This macro will generate a list of physicians and from the generated list
 * we should be able to generate the PHYS_ID-UPIN and PHYS_ID-NPI Xwalks in STATA */

%macro GenUpinNpiList(startyear=, endyear=);

    %do year = &startyear. %to &endyear.;

        %if &year.>=2006 %then %do;
            %let physid_prf=prf_upin prf_npi;
			%let physid_rfr=rfr_upin rfr_npi;
            %let physid_at=at_upin at_npi;
			%let physid_op=op_upin op_npi;
			%let physid_ot=ot_upin ot_npi;

            %let rename_prf=prf_upin=upin prf_npi=npi;
			%let rename_rfr=rfr_upin=upin rfr_npi=npi;
            %let rename_at=at_upin=upin at_npi=npi;
            %let rename_op=op_upin=upin op_npi=npi;
            %let rename_ot=ot_upin=upin ot_npi=npi;
        %end;

        %if &year.<=2005 %then %do;
            %let physid_prf=prf_upin;
            %let physid_rfr=rfr_upin;
            %let physid_at=at_upin;
            %let physid_op=op_upin;
            %let physid_ot=ot_upin;

            %let rename_prf=prf_upin=upin;
			%let rename_rfr=rfr_upin=upin;
            %let rename_at=at_upin=upin;
            %let rename_op=op_upin=upin;
            %let rename_ot=ot_upin=upin;
        %end;

        proc sort data=carIn.car20_clmline_raw_&year.(KEEP=&physid_prf. hcfaspcl OBS=&obs_num.)
            out=carrier_prf&year. nodupkey; by &physid_prf. hcfaspcl; run;
        proc sort data=carIn.car20_clmline_raw_&year.(KEEP=&physid_rfr. OBS=&obs_num.)
            out=carrier_rfr&year. nodupkey; by &physid_rfr.; run;

        proc sort data=opIn.op20_clms_raw_&year.(KEEP=&physid_at. OBS=&obs_num.)
            out=op_at&year. nodupkey; by &physid_at.; run;
        proc sort data=opIn.op20_clms_raw_&year.(KEEP=&physid_op. OBS=&obs_num.)
            out=op_op&year. nodupkey; by &physid_op.; run;
        proc sort data=opIn.op20_clms_raw_&year.(KEEP=&physid_ot. OBS=&obs_num.)
            out=op_ot&year. nodupkey; by &physid_ot.; run;

        proc sort data=ipIn.ip20_clms_raw_&year.(KEEP=&physid_at. OBS=&obs_num.)
            out=ip_at&year. nodupkey; by &physid_at.; run;
        proc sort data=ipIn.ip20_clms_raw_&year.(KEEP=&physid_op. OBS=&obs_num.)
            out=ip_op&year. nodupkey; by &physid_op.; run;
        proc sort data=ipIn.ip20_clms_raw_&year.(KEEP=&physid_ot. OBS=&obs_num.)
            out=ip_ot&year. nodupkey; by &physid_ot.; run;

        data upinnpilist&year.;
            set carrier_prf&year.(RENAME=(&rename_prf.))
				carrier_rfr&year.(RENAME=(&rename_rfr.))
                ip_at&year.(RENAME=(&rename_at.))
				ip_op&year.(RENAME=(&rename_op.))
				ip_ot&year.(RENAME=(&rename_ot.))
                op_at&year.(RENAME=(&rename_at.))
				op_op&year.(RENAME=(&rename_op.))
				op_ot&year.(RENAME=(&rename_ot.));
            upin = upcase(upin);
            informat npi $10. ;
        run;

      	proc sort data=upinnpilist&year. nodup; by upin npi hcfaspcl; run;

    %end;

    	data upinnpilist;
        	set %RepeatN(pfx=upinnpilist, Nlow=&startyear., Nhigh=&endyear.);
			by upin npi hcfaspcl;
    	run;

		proc sort data=upinnpilist out=upinnpilistsort nodup;
			by upin npi hcfaspcl;
		run;

      	proc export data=upinnpilistsort
            outfile="../output_local/UpinNpiList.csv"
            dbms=csv
            replace;
        run;
%mend;
