***********************************************************************;
** MACRO: THIS MACRO GENERATES INPUT FILES FOR THE RISK FACTOR STUFF **;
***********************************************************************;
%macro GenerateHCCInputData(pct=, year=);

    *********************************************;
    ** Carrier Data  ****************************;
    *********************************************;

    %GenerateCarrierYear(year=&year., pct=&pct.);

    data cartemp;
        set cartemp;
        line = _N_;
        keep &rawid. icd_dgns_cd: line;
    run;

    proc sort data=cartemp; by &rawid. line; run;

    proc transpose data=cartemp out=longcartemp;
        by &rawid. line;
        var icd_dgns_cd:;
    run;

    data longcartemp;
        set longcartemp;
        rename col1=diag;
        drop _name_ _label_ line;
    run;

    *********************************************;
    ** Outpatient Data  *************************;
    *********************************************;

    %GenerateOpClmsYear(year=&year., pct=&pct.);

    data opclmstemp;
        set opclmstemp;
        line=_N_;
        keep &rawid. icd_dgns_cd: line;
    run;

    proc sort data=opclmstemp; by &rawid. line; run;

    proc transpose data=opclmstemp out=longoptemp;
        by &rawid. line;
        var icd_dgns_cd:;
    run;

    data longoptemp;
        set longoptemp;
        rename col1=diag;
        drop _name_ _label_ line;
    run;

    *********************************************;
    ** Inpatient Data  **************************;
    *********************************************;

    %GenerateIpClmsYear(year=&year., pct=&pct.);

    data ipclmstemp;
        set ipclmstemp;
        line=_N_;
        keep &rawid. icd_dgns_cd: line;
    run;

    proc sort data=ipclmstemp; by &rawid. line; run;

    proc transpose data=ipclmstemp out=longiptemp;
        by &rawid. line;
        var icd_dgns_cd:;
    run;

    data longiptemp;
        set longiptemp;
        rename col1=diag;
        drop _name_ _label_ line;
    run;

    data hcc.hccdgns_&pct._&year.;
        set longiptemp longoptemp longcartemp;
        if diag ~= "";
    run;

    proc sort data = hcc.hccdgns_&pct._&year. nodupkey; by &rawid. diag; run;

%mend;
