version 12
version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries

program main
    identify_ed_related
    ip_events
    append_op_ed_related

    define_t0 
    drop_rev_dt_miss

    foreach year in 2008 {
        random_ip_event `year'
        drop_die_in_ed `year'
        drop_hmo `year'
        drop_partA_partB `year'
        define_mortality `year'
        merge_hrrs `year'
        gen_age_at_t0 `year'
        mcaid `year'
        save_sample `year' 
    }

end

program identify_ed_related
    foreach y in 08 09 10 {
        use bene_id clm_id rev_cntr using ../external_links/ip`y'/ipr20`y', clear
        gen ed_related = rev_cntr=="0981"
        forvalues c=450/459 {
            local code = "0"+"`c'"
            replace ed_related = 1 if rev_cntr=="`code'"
        }
        collapse (max) ed_related, by(bene_id clm_id)  
        drop if ed_related==0

        save_data ../output_local/ip`y'_ed_related.dta, key(bene_id clm_id) replace ///
            log(../output/data_file_manifest.log)
        describe using ../output_local/ip`y'_ed_related.dta
    }
    foreach y in 08 09 10 {
        use bene_id clm_id rev_cntr rev_dt using ../external_links/op`y'/opr20`y', clear
        gen ed_related = rev_cntr=="0981"
        forvalues c=450/459 {
            local code = "0"+"`c'"
            replace ed_related = 1 if rev_cntr=="`code'"
        }
        collapse (max) ed_related (min) rev_dt, by(bene_id clm_id)
        drop if ed_related==0

        save_data ../output_local/op`y'_ed_related.dta, key(bene_id clm_id) replace ///
            log(../output/data_file_manifest.log)
        describe using ../output_local/op`y'_ed_related.dta
    }
end


program ip_events
    foreach y in 08 09 {
        use ../external_links/ip`y'/ipc20`y', clear
        keep bene_id clm_id admsn_dt dgnscd1 
        rename dgnscd1 prncpal_dgns_cd
        save ../temp/ipc20`y'.dta, replace
    }
    use ../external_links/ip10/ipc2010, clear
    keep bene_id clm_id admsn_dt prncpal_dgns_cd
    save ../temp/ipc2010.dta, replace
    clear
    foreach y in 08 09 10 {
        append using ../temp/ipc20`y', keep(bene_id clm_id admsn_dt prncpal_dgns_cd)
    }
    foreach y in 08 09 10 {
        merge 1:1 bene_id clm_id using ../output_local/ip`y'_ed_related, assert(1 3) keep(1 3) nogen
    }
    replace ed_related = 0 if ed_related==.
    save ../temp/ip_events, replace
end

program append_op_ed_related
    foreach y in 08 09 {
        use bene_id clm_id dgnscd1 using ../external_links/op`y'/opc20`y', clear
        rename dgnscd1 prncpal_dgns_cd
        merge 1:1 bene_id clm_id using ../output_local/op`y'_ed_related, assert(1 3) keep(3) nogen
        save ../temp/op`y', replace
    }
    use bene_id clm_id prncpal_dgns_cd using ../external_links/op10/opc2010, clear
    merge 1:1 bene_id clm_id using ../output_local/op10_ed_related, assert(1 3) keep(3) nogen
    tempfile op10
    save ../temp/op10, replace

    clear
    foreach y in 08 09 10 {
        append using ../temp/op`y'
    }
    gen ip = 0
    append using ../temp/ip_events
    replace ip = 1 if ip==.
    save ../temp/events_all, replace
    // data has all ip claims and ed-related op claims (collapse to day below)
end

program define_t0
    use ../temp/events_all, clear
    gen t0 = rev_dt if ip==0
    replace t0 = admsn_dt if ip==1
    format %td t0
    gen event_month = month(t0)
    save ../temp/events, replace
end

program drop_rev_dt_miss
    use ../temp/events, clear
    scalar initial_event_claims = _N
    count if rev_dt==. & ip==0
    scalar mi_rev_drop = r(N)
    drop if rev_dt==. & ip==0  // some claims in OP ED have all claim lines with rev_dt==.
    save ../temp/events, replace
end

program random_ip_event
    args year
    use ../temp/events, clear
    keep if ip
    gen year = year(t0)
    label var year "year of event t0"
    keep if year == `year'
    set seed 32194
    gen rand = runiform()
    bys bene_id (rand): gen n = _n
    keep if n==1
    drop n rand year
    merge 1:m bene_id using ../external_links/denom/denom.dta, ///
      assert(2 3) keep(3) keepusing(*) nogen
    save ../temp/random_event_`year', replace
end

program drop_die_in_ed
    args year
    use ../temp/random_event_`year', clear
    gen days_t0_to_death_tmp = sdod-t0
    count if days_t0_to_death_tmp==0 & ip==0 & ed_related==1
    scalar op_ed_die_drop = r(N)
    drop if days_t0_to_death_tmp==0 & ip==0 & ed_related==1
    drop days_t0_to_death_tmp
    // if die in OP ED, then it's not an event; Predictable spending 7jul16 zo.docx
    save ../temp/random_event_`year', replace
end


program drop_hmo
    args year
    use ../temp/random_event_`year', clear
    gen pre_hmo_months = 0
    gen post_hmo_months = 0
    forvalues month=1/12 {
        gen pre_hmo_`month'_tmp = hmo_`month' if year==`year'-1
        egen pre_hmo_`month' = max(pre_hmo_`month'_tmp), by(bene_id)
        gen post_hmo_`month'_tmp = hmo_`month' if year==`year'+1
        egen post_hmo_`month' = max(post_hmo_`month'_tmp), by(bene_id)
        replace post_hmo_`month' = 0 if post_hmo_`month'==.
        drop pre_hmo_*_tmp post_hmo_*_tmp
        replace pre_hmo_months = pre_hmo_months + hmo_`month' if event_month > `month'
        replace pre_hmo_months = pre_hmo_months + pre_hmo_`month' if event_month <= `month'
        replace post_hmo_months = post_hmo_months + post_hmo_`month' if event_month > `month'
        replace post_hmo_months = post_hmo_months + hmo_`month' if event_month <= `month'
    }
    gen pre_hmo_no_months_tmp = pre_hmo_months==0 if year==`year'
    egen pre_hmo_no_months = max(pre_hmo_no_months_tmp), by(bene_id)
    gen post_hmo_no_months_tmp = post_hmo_months==0 if year==`year'
    egen post_hmo_no_months = max(post_hmo_no_months_tmp), by(bene_id)
    unique bene_id
    display "Unique IDs: " r(N)
    count if (!pre_hmo_no_months | !post_hmo_no_months) & year==`year'
    display "Patients in HMO in at least one month in pre- or post-year: " r(N)
    drop if !pre_hmo_no_months | !post_hmo_no_months
    save ../temp/sample_`year', replace
end

program drop_partA_partB
    args year
    use ../temp/sample_`year', clear
    gen partA_months = 0
    gen partB_months = 0
    forvalues month = 1/12 {
        gen prev_yr_pta_`month'_tmp = pta_`month' if year == `year' - 1
        gen prev_yr_ptb_`month'_tmp = ptb_`month' if year == `year' - 1
        egen prev_yr_pta_`month' = max(prev_yr_pta_`month'_tmp), by(bene_id)
        egen prev_yr_ptb_`month' = max(prev_yr_ptb_`month'_tmp), by(bene_id)
        drop prev_yr_*_tmp
        replace partA_months = partA_months + pta_`month' if event_month >= `month'
        replace partA_months = partA_months + prev_yr_pta_`month' if event_month <= `month'
        replace partB_months = partB_months + ptb_`month' if event_month >= `month'
        replace partB_months = partB_months + prev_yr_ptb_`month' if event_month <= `month'
    }
    gen partA_all_months_tmp = partA_months==13 if year==`year'
    gen partB_all_months_tmp = partB_months==13 if year==`year'
    egen partA_all_months = max(partA_all_months_tmp), by(bene_id)
    egen partB_all_months = max(partB_all_months_tmp), by(bene_id)
    unique bene_id
    display "Unique IDs: " r(N)
    count if (!partA_all_months | !partB_all_months) & year==`year'
    display "Patients without Part A and B in current month and 12 prior months: " r(N)
    drop if !partA_all_months | !partB_all_months
    save ../temp/base_`year', replace
end

program define_mortality
    args year
    use ../temp/base_`year', clear
    gen days_t0_to_death_tmp = sdod-t0 if year==`year'
    egen days_t0_to_death = max(days_t0_to_death_tmp), by(bene_id)
    drop days_t0_to_death_tmp
    drop if days_t0_to_death<0
    foreach d in 7 30 60 90 180 270 365 {
        gen mort`d' = days_t0_to_death<`d'
    }
    save ../temp/base_`year', replace
end

program merge_hrrs
    args year
    use ../temp/base_`year', clear
    format %05.0f zipcode
    tostring zipcode, u replace
    merge m:1 zipcode using ../external/hrrxw/ziphrrxwalk, ///
      assert(1 2 3) keep(3) keepusing(hrrnum) nogen
    * drop obs without hrrnum
    save ../temp/base_`year', replace
end

program gen_age_at_t0
    args year
    use ../temp/base_`year'.dta, clear
    gen age_at_t0 = year(t0) - year(sdob)
    replace age_at_t0 = year(t0) - year(sdob) - 1 if month(t0)<month(sdob)
    replace age_at_t0 = year(t0) - year(sdob) - 1 if day(t0)<day(sdob) & month(t0)==month(sdob)
    rename age_at_t0 age
    save ../temp/base_`year'.dta, replace
end

program mcaid
    args year
    use ../temp/base_`year', clear
    gen mcaid_months = 0
    forvalues month = 1/12 {
        gen prev_yr_mcaid_`month'_tmp = dual_`month' if year == `year' - 1
        egen prev_yr_mcaid_`month' = max(prev_yr_mcaid_`month'_tmp), by(bene_id)
        drop prev_yr_mcaid_*_tmp  
        replace mcaid_months = mcaid_months + dual_`month' if event_month >= `month'
        replace mcaid_months = mcaid_months + prev_yr_mcaid_`month' if event_month <= `month' 
    } 
    gen mcaid_any_month_tmp = mcaid_months>0 if year==`year'
    egen mcaid = max(mcaid_any_month_tmp), by(bene_id) 
    save ../temp/base_`year', replace 
end

program save_sample
    args year
    use ../temp/base_`year'.dta, clear
    replace sex = sex==2
    keep if year==`year'
    order bene_id t0 age days_t0_to_death ed_related ip sdob sdod ///
      mort* race sex mcaid state_de county_de zipcode hrrnum year
    order bene_id t0 age days_t0_to_death ed_related ip sdob sdod ///
      mort* race sex mcaid state_de county_de zipcode hrrnum year
    save_data ../output_local/event`year'.dta, key(bene_id) replace ///
      log(../output/data_file_manifest.log)
end

*EXECUTE
main
