/* These are macros that will generate annual data */

%let firstdatayear = 2007;
%let lastdatayear = 2011;
 
%macro GenerateCarrierYear(year=, pct=);

    ** Define Constants Used to Restrict by Date;
    %let startdate = %sysfunc(MDY(1, 1, &year.));
    %let enddate = %sysfunc(MDY(12, 31, &year.));
	
    %let keepCarrier = clm_id fileYear bene_id rfr_upin rfr_npi provzip icd_dgns_cd: hcpcs_cd
            from_dt thru_dt alowchrg lalowchg pmtdnlcd plcsrvc betos mdfr_cd1;
    %let renameCarrier = (clm_id=clm_id_old rfr_upin=upin rfr_npi=npi);
	
    %if (&year. >= &firstdatayear.) %then %do;
        data cartemp (drop=clm_id_old);
            length clm_id $&clm_id_length. upin $ &upin_length. npi $ &npi_length. 
                alowchrg &amt_length. lalowchg &amt_length.;
            set carIn.Car&pct._clmline_raw_&year.  (OBS=&obs_num. KEEP=&keepCarrier. RENAME=&renameCarrier.);
            where from_dt > &startdate. and from_dt <= &enddate.;
            clm_id = "Y"||PUT(fileYear,z4.)||"ID"||clm_id_old;
            format upin $&upin_length.. npi $&npi_length..;
            year= &year.;
        run;

    %end;

%mend GenerateCarrierYear;

%macro GenerateOpClmsYear(year=, pct=);

    ** Define Constants Used to Restrict by Date;
    %let startdate = %sysfunc(MDY(1, 1, &year.));
    %let enddate = %sysfunc(MDY(12, 31, &year.));

    %let keepOp = clm_id fileYear bene_id at_upin at_npi icd_dgns_cd: prstate
         from_dt thru_dt pmt_amt ptb_coin ptb_ded blddedam prpayamt provider;
    %let renameOp = (clm_id=clm_id_old at_upin=upin at_npi=npi);

    /* Since we've merge two files, the current clm_id vars are no longer unique
     * I fix this below be generating a new, unique claim id */
    %if (&year. >= &firstdatayear.) %then %do;
        data opclmstemp (DROP= clm_id_old);
            length upin $ &upin_length. npi $ &npi_length. pmt_amt &amt_length.
                ptb_coin &amt_length. ptb_ded &amt_length. blddedam &amt_length. prpayamt &amt_length.
                clm_id $&clm_id_length.;
            set opIn.Op&pct._clms_raw_&year.  (OBS=&obs_num. KEEP= &keepOp. RENAME= &renameOp.);
            where from_dt > &startdate. and from_dt <= &enddate.;
            clm_id = "Y"||PUT(fileYear,z4.)||"ID"||clm_id_old;
            year= &year.;
        run;

    %end;

%mend GenerateOpClmsYear;

%macro GenerateIpClmsYear(year=, pct=);

    ** Define Constants Used to Restrict by Date;
    %let startdate = %sysfunc(MDY(1, 1, &year.));
    %let enddate = %sysfunc(MDY(12, 31, &year.));
	
    %let keepIp = clm_id fileYear bene_id at_upin at_npi icd_dgns_cd: icd_prcdr_cd: drg_cd
        prstate from_dt thru_dt per_diem util_day pmt_amt ded_amt coin_amt blddedam prpayamt provider;
    %let renameIp = (clm_id=clm_id_old at_upin=upin at_npi=npi);

    %if (&year. >= &firstdatayear.) %then %do;
        data ipclmstemp (DROP=clm_id_old);
            length upin $ &upin_length. npi $ &npi_length. pmt_amt &amt_length. prpayamt &amt_length.
                per_diem &amt_length. util_day &amt_length. ded_amt &amt_length.  coin_amt &amt_length. blddedam &amt_length.
                clm_id $&clm_id_length.;;
            set ipIn.Ip&pct._clms_raw_&year.  (OBS=&obs_num. KEEP= &keepIp. RENAME= &renameIp.);
            where from_dt > &startdate. and from_dt <= &enddate.;
            clm_id = "Y"||PUT(fileYear,z4.)||"ID"||clm_id_old;
            year = &year.;
        run;
    %end;

%mend GenerateIpClmsYear;
