***************************************************************************************************;
* MAKE.SAS
*
* This file calls on macros to make the diagnosis data for the HCC risk score
*
***************************************************************************************************;

options pagesize=200;
options nocenter;
** These options create detailed log files;
options mprint mlogic;
options errorabend;
options msglevel=i;
options notes stimer fullstimer;
options formdlim=" ";
options mergenoby=error;
options filelocks=none;

*Output library;
libname hcc "../output_local";
*data libraries;
libname carIn "../external/carrier";
libname ipIn "../external/inpatient";
libname opIn "../external/outpatient";

*Additional Libraries;
libname bene "../external/bene";
libname out "../temp";

** load file containing various simple macros that make programming easier;
%include "./SASmacros/DataMacros.sas";
%include "./SASmacros/SampleCreationMacros.sas";
%include "./SASmacros/LoadPhysPatInfo.sas";

** load files with macros that allow me to use macro arrays;
%include "../external/lib/SASMacros/ARRAY.sas";
%include "../external/lib/SASMacros/DO_OVER.SAS";
%include "../external/lib/SASMacros/NUMLIST.SAS";
%include "../external/lib/SASMacros/HASHMERGE.sas";

%LoadPatInfo();

%let physid = phys_id;
%let rawid = bene_id;
%let obs_num = max;
%let npi_length = 12;
%let upin_length = 8;
%let bene_id_length = 15;
%let phys_id_length = 19;
%let zipcode_length = 5;
%let clm_id_length=22;
%let amt_length = 8;

** Run Macro to Generate UPIN_NPI List;
%macro main(pct=, startyear=, endyear=);
    %do year = &startyear. %to &endyear.;
        %GenerateHCCInputData(pct=&pct., year=&year.);
    %end;
%mend;

** Execute;
%main(pct=20, startyear=2007, endyear=2007);
%main(pct=20, startyear=2010, endyear=2010);
