version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    generate_patient_data, data("../external_links/denom/denom")
    hcc_patient_data, pct(20) startyear(2007) endyear(2007)
    hcc_patient_data, pct(20) startyear(2010) endyear(2010)
end

program generate_patient_data,
    syntax, data(string)

    use `data', clear
    destring zipcode, replace


    collapse (firstnm) sdob sdod race sex, by(bene_id)
    unique bene_id

    ** Label variables
    label var bene_id "Beneficiary ID"
    label var sdod "Date of Death"
    label var sdob "Date of Birth"
    label var race "Beneficiary Race"
    label var sex "Beneficiary Sex"
    label define race_lab 0 "unknown" 1 "white" 2 "black" 3 "other" 4 "asian" 5 "hispanic" ///
        6 "north american native"
    label define sex_lab 0 "female" 1 "male"
    label values sex sex_lab
    label values race race_lab

    save_data ../output_local/CharsPatient.dta, ///
        replace key(bene_id) log("../output/data_file_manifest.log")
    keep bene_id sdod
    save_data ../output_local/sdod_list.csv if sdod!=., outsheet delim(",") ///
        replace key(bene_id) log("../output/data_file_manifest.log")
    keep bene_id
    save_data ../output_local/samp_list.dta, ///
        replace key(bene_id) log("../output/data_file_manifest.log")
    save_data ../output_local/samp_list.csv, outsheet delim(",") ///
        replace key(bene_id) log("../output/data_file_manifest.log")
end

program hcc_patient_data,
    syntax, pct(string) startyear(real) endyear(real)
    forval year = `startyear'/`endyear'{
        local next_year = `year' + 1
        use if year==`year' using ../external_links/denom/denom, clear
        merge 1:1 bene_id using ../external_links/jan/1jan`next_year', ///
          assert(1 2 3) keep(3) keepusing(mcaid) nogen
        replace sex=2 if sex==0
        format sdob %td
        rename sdob dob
        gen nemcaid = 0 // generating this variable follows DOCS and DIE
        keep bene_id sex dob mcaid nemcaid orec
        save_data ../output_local/hccperson_`pct'_`year'.csv, outsheet delim(",") ///
            replace key(bene_id) log("../output/data_file_manifest.log")
    }
end

* EXECUTE
main
