version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries
set maxvar 32767, perm
set emptycells drop, perm
set matsize 11000, perm

program main 
    mort30
    split_test
    split_calibration
    balance_training
    split_folds
end

program mort30
    use ../external_links/samples/test, clear
    append using ../external_links/samples/train
    append using ../external_links/samples/calibrate
    drop mort*
    merge 1:1 bene_id using ../external_links/events/event2008, ///
        assert(3) keep(3) keepusing(days_t0_to_death) nogen
    gen mort = days_t0_to_death < 30
    drop days_t0_to_death 
    order mort
    save ../temp/cleaned, replace
end

program split_test
    use ../temp/cleaned, clear
    sort bene_id
    set seed 1
    gen u = runiform()
    gen byte test = u > 2/3
    preserve
    keep if test == 1
    drop u test 
    saveold ../output_local/test, replace v(12)
    restore
    keep if test == 0
    drop u test 
end

program split_calibration
    set seed 2
    gen u = runiform()
    gen byte calibrate = u > .9
    preserve
    keep if calibrate == 1
    drop u calibrate
    saveold ../output_local/calibrate, replace v(12)
    set seed 3
    gen u = runiform()
    count if mort == 1
    sort mort u
    gen keep = 1 in 1/`r(N)'
    replace keep = 1 if mort == 1
    keep if keep == 1
    drop u keep
    saveold ../output_local/calibrate-balanced, replace v(12)
    restore
    keep if calibrate == 0
    drop u calibrate
    saveold ../output_local/train, replace v(12)
end

program balance_training
    set seed 4
    count if mort == 1
    local N = `r(N)'
    gen u = runiform()
    sort mort u 
    gen keep = 1 in 1/`N'
    keep if keep == 1 | mort == 1
    drop keep u
end

program split_folds
    set seed 5
    gen u = runiform()
    gen cv1 = u < .2
    gen cv2 = u >= .2 & u < .4
    gen cv3 = u >= .4 & u < .6
    gen cv4 = u >= .6 & u < .8
    gen cv5 = u >= .8
    save ../output_local/allfolds, replace
    forvalues c = 1/5 {
        use ../output_local/allfolds, clear
        drop if cv`c' == 1
        drop u cv?
        saveold ../output_local/train-less-fold`c', replace v(12)
        use ../output_local/allfolds, clear 
        keep if cv`c' == 1
        drop u cv?
        saveold ../output_local/fold`c', replace v(12)
    }
    use ../output_local/allfolds, clear
    drop u cv?  
    saveold ../output_local/allfolds, replace v(12)
end

*EXECUTE
main
