/************************************************************************************
Program is based off the following:
Program Name: SingleDXCCS.do 
Description : Assign Single-Level Diagnosis CCS category array (DXCCS#) from Stata. 
Developed   : By Bob Houchens
Updated     : By David Ross on 10/27/2009.
            : By David Ross and Nils Nordstrand on 11/03/2016 incorporating updates from Rebecca Pope (StataCorp).
************************************************************************************/
local modern = 1

local vv : di "version " string(_caller()) ":"
*
unab varlist: DX*
local _ndx: word count `varlist'
*
* Generate a temporary diagnosis variable that will be reformatted by the clean function in preparation for the merge
*
generate _DX = DX
*
* Check the validity of the diagnosis code
*
tempvar invalid
capture icd9 check _DX, generate(`invalid')
*
* Format the temporary diagnosis to match the format in SingleDXCCS.dta  
*
qui icd9 clean _DX, dots
*
* Merge the CCS category variable, DXCCS, that matches the temporary diagnosis
*
merge m:1 _DX using SingleDXCCS, keep(1 3) nogen 
capture drop _DX
