version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries
set varabbrev off
set maxvar 32000

program main 
    args days
    data `days'
    drop_vars_not_used_for_rf
    split_test
    split_calibration
    balance_training
    split_folds
    split_train_test
end

program data
    args days
    use bene_id-year using ../external_links/jan/1jan2008, clear

    merge 1:1 bene_id using ../external/util/prior_pmt_y08, ///
        assert(3) keep(3) keepusing(*) nogen
    merge 1:1 bene_id using ../external/util/prior_ip_y08, ///
        assert(3) keep(3) keepusing(num_*) nogen
    merge 1:1 bene_id using ../external/util/prior_op_y08, ///
        assert(3) keep(3) keepusing(num_*) nogen

    foreach m in 01 112 {
        merge 1:1 bene_id using ../external/zo_cats/zc_m`m'_y08, ///
            assert(1 3) keep(1 3) keepusing(m`m'_zc*) nogen
    }
    foreach d in 01 03 07 {
        merge 1:1 bene_id using ../external/zo_cats/zc_d`d'_y08, ///
            assert(1 3) keep(1 3) keepusing(d`d'_zc*) nogen
    }

    foreach m in 01 03 36 69 912 {
        merge 1:1 bene_id using ../external/gagne/gn_m`m'_y08, ///
            assert(1 2 3) keep(1 3) keepusing(m`m'*) nogen
    }
    foreach d in 01 03 07 {
        merge 1:1 bene_id using ../external/gagne/gn_d`d'_y08, ///
            assert(1 2 3) keep(1 3) keepusing(d`d'*) nogen
    }

    merge 1:1 bene_id year using ../external/hcc/HCC_y08.dta, ///
      assert(3) keep(3) keepusing(score_community) nogen

    merge 1:1 bene_id using ../external/chronic/chronic_y08.dta, ///
      assert(3) keep(3) keepusing($chronic_conditions) nogen

    merge 1:1 bene_id using ../external/visits/physician_visits_y08.dta, ///
      assert(1 3) keep(1 3) keepusing(primary* specialist*) nogen
    drop mort*
    gen days_survived = days_t0_to_death
    replace days_survived = `days' if days_survived > `days'
    gen mort = days_survived < `days'
    drop days_survived days_t0_to_death
    save ../temp/data08, replace
end

program drop_vars_not_used_for_rf
    use ../temp/data08, clear
    drop t0 sdo? 
    drop state_de county_de zipcode year
    tab hrrnum, gen(hrr)
    drop hrrnum 
    count
    global zct = floor(.001*`r(N)')
    forvalues z = 1/3000 {
        foreach t in 01 112 {
            capture confirm variable m`t'_zc`z'
	    if !_rc {
		replace m`t'_zc`z' = 0 if m`t'_zc`z' == .
		count if m`t'_zc`z' != 0
		if `r(N)' <= $zct {
		    drop m`t'_zc`z'
		}
	    }
        }
        foreach t in 01 03 07 {
            capture confirm variable d`t'_zc`z'
	    if !_rc {
                replace d`t'_zc`z' = 0 if d`t'_zc`z' == .
		count if d`t'_zc`z' != 0
		if `r(N)' < $zct {
		    drop d`t'_zc`z'
		}
	    }
        }
    }
    foreach v of varlist m01alcohol_elixhauser -d07wtloss_elixhauser { 
        replace `v' = 0 if `v' == .
    }
    foreach v of varlist primary* specialist* {
        replace `v' = 0 if `v' == .
    }
    order mort
    compress
    save ../temp/cleaned, replace
end

program split_test
    use ../temp/cleaned, clear
    sort bene_id
    set seed 1
    gen u = runiform()
    gen byte test = u > 2/3 
    preserve
    keep if test == 1
    drop u test 
    saveold ../output_local/test, replace v(12)
    restore
    keep if test == 0
    drop u test 
end

program split_calibration
    set seed 1
    gen u = runiform()
    gen byte calibrate = u > .9
    preserve
    keep if calibrate == 1
    drop u calibrate
    saveold ../output_local/calibrate, replace v(12)
    set seed 1
    gen u = runiform()
    count if mort == 1
    sort mort u
    gen keep = 1 in 1/`r(N)'
    replace keep = 1 if mort == 1
    keep if keep == 1
    drop u keep
    saveold ../output_local/calibrate-balanced, replace v(12)
    restore
    keep if calibrate == 0
    drop u calibrate
    saveold ../output_local/train, replace v(12)
end

program balance_training
    set seed 1
    count if mort == 1
    local N = `r(N)'
    gen u = runiform()
    sort mort u 
    gen keep = 1 in 1/`N'
    keep if keep == 1 | mort == 1
    drop keep u
end

program split_folds
    set seed 1
    gen u = runiform()
    gen cv1 = u < .2
    gen cv2 = u >= .2 & u < .4
    gen cv3 = u >= .4 & u < .6
    gen cv4 = u >= .6 & u < .8
    gen cv5 = u >= .8
    save ../output_local/allfolds, replace
    forvalues c = 1/5 {
        use ../output_local/allfolds, clear
        drop if cv`c' == 1
        drop u cv?
        saveold ../output_local/train-less-fold`c', replace v(12)
        use ../output_local/allfolds, clear 
        keep if cv`c' == 1
        drop u cv?
        saveold ../output_local/fold`c', replace v(12)
    }
    use ../output_local/allfolds, clear
    drop u cv?
    saveold ../output_local/allfolds, replace v(12)
end

program split_train_test
    use ../output_local/train, clear
    count
    local L = r(N)
    local D = floor(`L'/200000)
    forvalues d = 1/`D' {
        local min = (`d'-1)*200000 + 1
        local max = `d'*200000
        use ../output_local/train in `min'/`max', clear
        saveold ../output_local/train`d', v(12) replace
    }
    local l = `D'*200000 + 1
    local DD = `D' + 1
    use ../output_local/train in `l'/`L', clear
    saveold ../output_local/train`DD', v(12) replace
    use ../output_local/test, clear
    count
    local L = r(N)
    local D = floor(`L'/200000)
    forvalues d = 1/`D' {
	local min = (`d'-1)*200000 + 1
	local max = `d'*200000
	use ../output_local/test in `min'/`max', clear
	saveold ../output_local/test`d', v(12) replace
    }
    local l = `D'*200000 + 1
    local DD = `D' + 1
    use ../output_local/test in `l'/`L', clear
    saveold ../output_local/test`DD', v(12) replace
end

*EXECUTE
main 365
