#! /usr/bin/env python

import os
import shutil

from private.preliminaries import start_logging, end_logging, input_to_array, print_error
from private.getexternalsdirectives import SystemDirective, SvnExportDirective, CopyDirective
import private.metadata as metadata
import private.messages as messages

######################################################
# Main Program
######################################################

def get_externals(externals_file,
                  external_dir = '@DEFAULTVALUE@',
                  makelog = '@DEFAULTVALUE@',
                  quiet = False):
    """Please see /trunk/lib/python/gslab_make/py/readme_getexternals.txt for more information."""

    # metadata.settings should not be part of argument defaults so that they can be
    # overwritten by make_log.set_option
    try:
		if makelog == '@DEFAULTVALUE@':
			makelog = metadata.settings['makelog_file']
		if external_dir == '@DEFAULTVALUE@':
			external_dir = metadata.settings['external_dir']
		if external_dir[-1:] != '/':
			external_dir = external_dir + '/'

		# Run preliminaries
		LOGFILE = start_logging(metadata.settings['externalslog_file'], 'get_externals.py')
		if externals_file!='externals.txt':
			print >> LOGFILE, messages.note_extfilename
		externals = input_to_array(externals_file)

		# Prepare last rev/dir variables
		last_dir = ''
		last_rev = ''

		# Create new externals folder
		if os.path.exists(external_dir):
			shutil.rmtree(external_dir)
		os.makedirs(external_dir)

		# Run System Directive
		for line in externals:
			try:
				directive = SystemDirective(line, LOGFILE, last_dir, last_rev)
				directive.error_check()
				directive.clean(external_dir)
				directive.issue_sys_command(quiet)

				# Save rev/dir for next line
				last_dir = directive.dir
				last_rev = directive.rev
			except:
				print_error(LOGFILE)
		end_logging(LOGFILE, makelog, 'get_externals.py')
    except Exception as errmsg:
        print "Error with get_external: \n", errmsg