#! /usr/bin/env python

import unittest, sys, os, shutil, contextlib
sys.path.append('..')
from py.dir_mod import delete_all_files
from py.get_externals import get_externals
from nostderrout import nostderrout


class testDeleteAllFiles(unittest.TestCase):

    def setUp(self):
        os.mkdir('./input/externals_delete_all_files/')
        get_externals('./input/externals_delete_all_files.txt', './input/externals_delete_all_files/', '', quiet = True)
        
    def test_all(self):
        file_list = os.listdir('./input/externals_delete_all_files/')
        self.assertTrue(len(file_list) > 0)
        subdirectory_file_list = os.listdir('./input/externals_delete_all_files/internal')
        self.assertTrue(len(subdirectory_file_list) > 0)
        with nostderrout():
            delete_all_files('./input/externals_delete_all_files/')
        file_list = os.listdir('./input/externals_delete_all_files/')
        self.assertEqual(len(file_list), 1)
        subdirectory_file_list = os.listdir('./input/externals_delete_all_files/internal')
        self.assertEqual(len(subdirectory_file_list), 0)
    
    def test_except(self):
        file_list = os.listdir('./input/externals_delete_all_files/')
        self.assertTrue(len(file_list) > 0)
        subdirectory_file_list = os.listdir('./input/externals_delete_all_files/internal')
        self.assertTrue(len(subdirectory_file_list) > 0)
        with nostderrout():
            delete_all_files('./input/externals_delete_all_files/', 'texttables.txt')
        file_list = os.listdir('./input/externals_delete_all_files/')
        self.assertEqual(len(file_list), 2)
        self.assertTrue(os.path.isfile('./input/externals_delete_all_files/texttables.txt'))
        subdirectory_file_list = os.listdir('./input/externals_delete_all_files/internal')
        self.assertEqual(len(subdirectory_file_list), 0)
        
    def tearDown(self):
        if os.path.isdir('./input/externals_delete_all_files/'):
            shutil.rmtree('./input/externals_delete_all_files/')
        if os.path.isfile('get_externals.log'):
            os.remove('get_externals.log')
    
if __name__ == '__main__':
    os.getcwd()
    unittest.main()