#! /usr/bin/env python

import unittest, sys, os, shutil, contextlib
sys.path.append('..')
from py.make_log import start_make_logging
from py.dir_mod import clear_output_dirs
from py.run_program import run_stcmd
from nostderrout import nostderrout
    

class testRunStcmd(unittest.TestCase):

    def setUp(self):
        makelog_file = '../output/make.log'
        output_dir = '../output/'
        with nostderrout():
            clear_output_dirs(output_dir, '')
            start_make_logging(makelog_file)

    def test_default_log(self):
        with nostderrout():
            run_stcmd(program = './input/stcmd_test_script.stcmd')
        logfile_data = open('../output/make.log', 'rU').readlines()
        self.assertTrue(logfile_data[-2].startswith('4 cases were transferred'))
        self.assertTrue(os.path.isfile('../output/test_data.csv'))
        
    def test_custom_log(self):
        os.remove('../output/make.log')
        makelog_file = '../output/custom_make.log'
        output_dir = '../output/'
        with nostderrout():
            clear_output_dirs(output_dir, '')
            start_make_logging(makelog_file)
            run_stcmd(program = './input/stcmd_test_script.stcmd', makelog = '../output/custom_make.log')
        logfile_data = open('../output/custom_make.log', 'rU').readlines()
        self.assertTrue(logfile_data[-2].startswith('4 cases were transferred'))
        self.assertTrue(os.path.isfile('../output/test_data.csv'))
        
    def test_independent_log(self):
        with nostderrout():
            run_stcmd(program = './input/stcmd_test_script.stcmd', log = '../output/stcmd.log')
        makelog_data = open('../output/make.log', 'rU').readlines()
        self.assertTrue(makelog_data[-2].startswith('4 cases were transferred'))
        self.assertTrue(os.path.isfile('../output/stcmd.log'))
        stcmdlog_data = open('../output/stcmd.log', 'rU').readlines()
        self.assertTrue(stcmdlog_data[-2].startswith('4 cases were transferred'))
        self.assertTrue(os.path.isfile('../output/test_data.csv'))    

    def test_no_extension(self):
        with nostderrout():
            run_stcmd(program = './input/stcmd_test_script')
        logfile_data = open('../output/make.log', 'rU').readlines()
        self.assertTrue(logfile_data[-2].startswith('4 cases were transferred'))
        self.assertTrue(os.path.isfile('../output/test_data.csv'))
        
    def test_executable(self):
        with nostderrout():
            run_stcmd(program = './input/stcmd_test_script.stcmd', executable = 'st') 
        logfile_data = open('../output/make.log', 'rU').readlines()
        self.assertTrue(logfile_data[-2].startswith('4 cases were transferred'))
        self.assertTrue(os.path.isfile('../output/test_data.csv'))
        
    def test_bad_executable(self):
        with nostderrout():
            run_stcmd(program = './input/stcmd_test_script.stcmd', executable = 'nonexistent_st_executable')
        logfile_data = open('../output/make.log', 'rU').read()
        self.assertIn('\'nonexistent_st_executable\' is not recognized as an internal or external command', logfile_data)
    
    def test_no_program(self):
        with nostderrout():
            run_stcmd(program = './input/nonexistent_stcmd_script.stcmd')
        logfile_data = open('../output/make.log', 'rU').readlines()
        self.assertTrue(logfile_data[-1].startswith('CritError:'))
    
    def test_change_dir(self):        
        with nostderrout():
            run_stcmd(program = './input/stcmd_test_script.stcmd', changedir = True)
        logfile_data = open('../output/make.log', 'rU').read()
        self.assertIn('The file: ./input/test_data.xls does not exist.', logfile_data)  
    
    def tearDown(self):
        if os.path.isdir('../output/'):
            shutil.rmtree('../output/')
        if os.path.isfile('convert.log'):
            os.remove('convert.log')
        if os.path.isfile('./input/convert.log'):
            os.remove('./input/convert.log')
                
if __name__ == '__main__':
    os.getcwd()
    unittest.main()