** PROGRAM STRUCTURE;
** I call macros separately by year at the end ;
* This file combines all of Maurice's code in one file';

options pagesize=200;
options nocenter;
** These options create detalied log files;
options mprint mlogic;
*options errorabend;
options msglevel=i;
options notes stimer fullstimer;
options formdlim=" ";
options mergenoby=error;
options spool;

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES for the 05 pct Extract;
%include "./dirInit.sas";

libname bene "&bene_id_xw_root.";
libname spDenom "&spden.";
libname outDen "&denExt.";

** load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./decompressDenom.sas";
** load files with macros that conform the files of various years into a common format;
%include "&SASmac./ConformDenom.sas";

** load files with macros that will run extraction code;
%include "&SASmac./ExtractDenom.sas";

********************************************************************************************************;
******************************                WRAPPER MACROS         ***********************************;
********************************************************************************************************;
%macro runDenomExtract(pct=, startyear=, endyear=);

    %do yr =&startyear. %to &endyear.;

	** Clear out the output folder to avoid duplicating entries;
	x "rm -f &denExt./denom&pct.*.sas* ";

        ** This macro will unzip the proper compress denom file ,outdir=&spden.,outlib=outDen;
        %decompressDenom(yr=&yr.,pct=&pct.,outlib=outden,outdir=&spden.);

        data outDen.denom&pct.&yr._cnfm (rename=zipcode_cnfm=zipcode);
            set spdenom.denom&pct._&yr._all;
            ** Convert the file format for this year into a standard form;
            %ConformDenom(year=&yr.,adVar=year ehic bene_id);
            year = &yr.;
        run;

        ** Merge in BENE_ID for years prior to 2006;
        %if &yr. < 2006 %then %do;
            %MergeDenomBene(pct=&pct., year=&yr.);
        %end;

        ** export as excel file;
        proc export data=outDen.denom&pct.&yr._cnfm
            outfile="&denExt./denom&pct.&yr._cnfm.csv"
            dbms=csv
            replace;
        run;

        ** delete sas files;
        proc datasets library=outDen;
            delete denom&pct.&yr._cnfm;
        run;

        proc datasets library=outDen;
            delete denom&pct._&yr.;
        run;

    %end;

%mend;


*************************************************************************;
************    RUN MACROS                                    ***********;
*************************************************************************;
%runDenomExtract(pct=20, startyear=2012, endyear=2012);



